.container {
  margin-right: auto;
  margin-left: auto;
  padding-left: 15px;
  padding-right: 15px;
}
@media (min-width: 768px) {
  .container {
    width: 750px;
  }
}
@media (min-width: 992px) {
  .container {
    width: 970px;
  }
}
@media (min-width: 1200px) {
  .container {
    width: 1170px;
  }
}
.container-fluid {
  margin-right: auto;
  margin-left: auto;
  padding-left: 15px;
  padding-right: 15px;
}
.row {
  margin-left: -15px;
  margin-right: -15px;
}
.col-xs-1,
.col-sm-1,
.col-md-1,
.col-lg-1,
.col-xs-2,
.col-sm-2,
.col-md-2,
.col-lg-2,
.col-xs-3,
.col-sm-3,
.col-md-3,
.col-lg-3,
.col-xs-4,
.col-sm-4,
.col-md-4,
.col-lg-4,
.col-xs-5,
.col-sm-5,
.col-md-5,
.col-lg-5,
.col-xs-6,
.col-sm-6,
.col-md-6,
.col-lg-6,
.col-xs-7,
.col-sm-7,
.col-md-7,
.col-lg-7,
.col-xs-8,
.col-sm-8,
.col-md-8,
.col-lg-8,
.col-xs-9,
.col-sm-9,
.col-md-9,
.col-lg-9,
.col-xs-10,
.col-sm-10,
.col-md-10,
.col-lg-10,
.col-xs-11,
.col-sm-11,
.col-md-11,
.col-lg-11,
.col-xs-12,
.col-sm-12,
.col-md-12,
.col-lg-12 {
  position: relative;
  min-height: 1px;
  padding-left: 15px;
  padding-right: 15px;
}
.col-xs-1,
.col-xs-2,
.col-xs-3,
.col-xs-4,
.col-xs-5,
.col-xs-6,
.col-xs-7,
.col-xs-8,
.col-xs-9,
.col-xs-10,
.col-xs-11,
.col-xs-12 {
  float: left;
}
.col-xs-12 {
  width: 100%;
}
.col-xs-11 {
  width: 91.66666667%;
}
.col-xs-10 {
  width: 83.33333333%;
}
.col-xs-9 {
  width: 75%;
}
.col-xs-8 {
  width: 66.66666667%;
}
.col-xs-7 {
  width: 58.33333333%;
}
.col-xs-6 {
  width: 50%;
}
.col-xs-5 {
  width: 41.66666667%;
}
.col-xs-4 {
  width: 33.33333333%;
}
.col-xs-3 {
  width: 25%;
}
.col-xs-2 {
  width: 16.66666667%;
}
.col-xs-1 {
  width: 8.33333333%;
}
.col-xs-pull-12 {
  right: 100%;
}
.col-xs-pull-11 {
  right: 91.66666667%;
}
.col-xs-pull-10 {
  right: 83.33333333%;
}
.col-xs-pull-9 {
  right: 75%;
}
.col-xs-pull-8 {
  right: 66.66666667%;
}
.col-xs-pull-7 {
  right: 58.33333333%;
}
.col-xs-pull-6 {
  right: 50%;
}
.col-xs-pull-5 {
  right: 41.66666667%;
}
.col-xs-pull-4 {
  right: 33.33333333%;
}
.col-xs-pull-3 {
  right: 25%;
}
.col-xs-pull-2 {
  right: 16.66666667%;
}
.col-xs-pull-1 {
  right: 8.33333333%;
}
.col-xs-pull-0 {
  right: auto;
}
.col-xs-push-12 {
  left: 100%;
}
.col-xs-push-11 {
  left: 91.66666667%;
}
.col-xs-push-10 {
  left: 83.33333333%;
}
.col-xs-push-9 {
  left: 75%;
}
.col-xs-push-8 {
  left: 66.66666667%;
}
.col-xs-push-7 {
  left: 58.33333333%;
}
.col-xs-push-6 {
  left: 50%;
}
.col-xs-push-5 {
  left: 41.66666667%;
}
.col-xs-push-4 {
  left: 33.33333333%;
}
.col-xs-push-3 {
  left: 25%;
}
.col-xs-push-2 {
  left: 16.66666667%;
}
.col-xs-push-1 {
  left: 8.33333333%;
}
.col-xs-push-0 {
  left: auto;
}
.col-xs-offset-12 {
  margin-left: 100%;
}
.col-xs-offset-11 {
  margin-left: 91.66666667%;
}
.col-xs-offset-10 {
  margin-left: 83.33333333%;
}
.col-xs-offset-9 {
  margin-left: 75%;
}
.col-xs-offset-8 {
  margin-left: 66.66666667%;
}
.col-xs-offset-7 {
  margin-left: 58.33333333%;
}
.col-xs-offset-6 {
  margin-left: 50%;
}
.col-xs-offset-5 {
  margin-left: 41.66666667%;
}
.col-xs-offset-4 {
  margin-left: 33.33333333%;
}
.col-xs-offset-3 {
  margin-left: 25%;
}
.col-xs-offset-2 {
  margin-left: 16.66666667%;
}
.col-xs-offset-1 {
  margin-left: 8.33333333%;
}
.col-xs-offset-0 {
  margin-left: 0%;
}
@media (min-width: 768px) {
  .col-sm-1,
  .col-sm-2,
  .col-sm-3,
  .col-sm-4,
  .col-sm-5,
  .col-sm-6,
  .col-sm-7,
  .col-sm-8,
  .col-sm-9,
  .col-sm-10,
  .col-sm-11,
  .col-sm-12 {
    float: left;
  }
  .col-sm-12 {
    width: 100%;
  }
  .col-sm-11 {
    width: 91.66666667%;
  }
  .col-sm-10 {
    width: 83.33333333%;
  }
  .col-sm-9 {
    width: 75%;
  }
  .col-sm-8 {
    width: 66.66666667%;
  }
  .col-sm-7 {
    width: 58.33333333%;
  }
  .col-sm-6 {
    width: 50%;
  }
  .col-sm-5 {
    width: 41.66666667%;
  }
  .col-sm-4 {
    width: 33.33333333%;
  }
  .col-sm-3 {
    width: 25%;
  }
  .col-sm-2 {
    width: 16.66666667%;
  }
  .col-sm-1 {
    width: 8.33333333%;
  }
  .col-sm-pull-12 {
    right: 100%;
  }
  .col-sm-pull-11 {
    right: 91.66666667%;
  }
  .col-sm-pull-10 {
    right: 83.33333333%;
  }
  .col-sm-pull-9 {
    right: 75%;
  }
  .col-sm-pull-8 {
    right: 66.66666667%;
  }
  .col-sm-pull-7 {
    right: 58.33333333%;
  }
  .col-sm-pull-6 {
    right: 50%;
  }
  .col-sm-pull-5 {
    right: 41.66666667%;
  }
  .col-sm-pull-4 {
    right: 33.33333333%;
  }
  .col-sm-pull-3 {
    right: 25%;
  }
  .col-sm-pull-2 {
    right: 16.66666667%;
  }
  .col-sm-pull-1 {
    right: 8.33333333%;
  }
  .col-sm-pull-0 {
    right: auto;
  }
  .col-sm-push-12 {
    left: 100%;
  }
  .col-sm-push-11 {
    left: 91.66666667%;
  }
  .col-sm-push-10 {
    left: 83.33333333%;
  }
  .col-sm-push-9 {
    left: 75%;
  }
  .col-sm-push-8 {
    left: 66.66666667%;
  }
  .col-sm-push-7 {
    left: 58.33333333%;
  }
  .col-sm-push-6 {
    left: 50%;
  }
  .col-sm-push-5 {
    left: 41.66666667%;
  }
  .col-sm-push-4 {
    left: 33.33333333%;
  }
  .col-sm-push-3 {
    left: 25%;
  }
  .col-sm-push-2 {
    left: 16.66666667%;
  }
  .col-sm-push-1 {
    left: 8.33333333%;
  }
  .col-sm-push-0 {
    left: auto;
  }
  .col-sm-offset-12 {
    margin-left: 100%;
  }
  .col-sm-offset-11 {
    margin-left: 91.66666667%;
  }
  .col-sm-offset-10 {
    margin-left: 83.33333333%;
  }
  .col-sm-offset-9 {
    margin-left: 75%;
  }
  .col-sm-offset-8 {
    margin-left: 66.66666667%;
  }
  .col-sm-offset-7 {
    margin-left: 58.33333333%;
  }
  .col-sm-offset-6 {
    margin-left: 50%;
  }
  .col-sm-offset-5 {
    margin-left: 41.66666667%;
  }
  .col-sm-offset-4 {
    margin-left: 33.33333333%;
  }
  .col-sm-offset-3 {
    margin-left: 25%;
  }
  .col-sm-offset-2 {
    margin-left: 16.66666667%;
  }
  .col-sm-offset-1 {
    margin-left: 8.33333333%;
  }
  .col-sm-offset-0 {
    margin-left: 0%;
  }
}
@media (min-width: 992px) {
  .col-md-1,
  .col-md-2,
  .col-md-3,
  .col-md-4,
  .col-md-5,
  .col-md-6,
  .col-md-7,
  .col-md-8,
  .col-md-9,
  .col-md-10,
  .col-md-11,
  .col-md-12 {
    float: left;
  }
  .col-md-12 {
    width: 100%;
  }
  .col-md-11 {
    width: 91.66666667%;
  }
  .col-md-10 {
    width: 83.33333333%;
  }
  .col-md-9 {
    width: 75%;
  }
  .col-md-8 {
    width: 66.66666667%;
  }
  .col-md-7 {
    width: 58.33333333%;
  }
  .col-md-6 {
    width: 50%;
  }
  .col-md-5 {
    width: 41.66666667%;
  }
  .col-md-4 {
    width: 33.33333333%;
  }
  .col-md-3 {
    width: 25%;
  }
  .col-md-2 {
    width: 16.66666667%;
  }
  .col-md-1 {
    width: 8.33333333%;
  }
  .col-md-pull-12 {
    right: 100%;
  }
  .col-md-pull-11 {
    right: 91.66666667%;
  }
  .col-md-pull-10 {
    right: 83.33333333%;
  }
  .col-md-pull-9 {
    right: 75%;
  }
  .col-md-pull-8 {
    right: 66.66666667%;
  }
  .col-md-pull-7 {
    right: 58.33333333%;
  }
  .col-md-pull-6 {
    right: 50%;
  }
  .col-md-pull-5 {
    right: 41.66666667%;
  }
  .col-md-pull-4 {
    right: 33.33333333%;
  }
  .col-md-pull-3 {
    right: 25%;
  }
  .col-md-pull-2 {
    right: 16.66666667%;
  }
  .col-md-pull-1 {
    right: 8.33333333%;
  }
  .col-md-pull-0 {
    right: auto;
  }
  .col-md-push-12 {
    left: 100%;
  }
  .col-md-push-11 {
    left: 91.66666667%;
  }
  .col-md-push-10 {
    left: 83.33333333%;
  }
  .col-md-push-9 {
    left: 75%;
  }
  .col-md-push-8 {
    left: 66.66666667%;
  }
  .col-md-push-7 {
    left: 58.33333333%;
  }
  .col-md-push-6 {
    left: 50%;
  }
  .col-md-push-5 {
    left: 41.66666667%;
  }
  .col-md-push-4 {
    left: 33.33333333%;
  }
  .col-md-push-3 {
    left: 25%;
  }
  .col-md-push-2 {
    left: 16.66666667%;
  }
  .col-md-push-1 {
    left: 8.33333333%;
  }
  .col-md-push-0 {
    left: auto;
  }
  .col-md-offset-12 {
    margin-left: 100%;
  }
  .col-md-offset-11 {
    margin-left: 91.66666667%;
  }
  .col-md-offset-10 {
    margin-left: 83.33333333%;
  }
  .col-md-offset-9 {
    margin-left: 75%;
  }
  .col-md-offset-8 {
    margin-left: 66.66666667%;
  }
  .col-md-offset-7 {
    margin-left: 58.33333333%;
  }
  .col-md-offset-6 {
    margin-left: 50%;
  }
  .col-md-offset-5 {
    margin-left: 41.66666667%;
  }
  .col-md-offset-4 {
    margin-left: 33.33333333%;
  }
  .col-md-offset-3 {
    margin-left: 25%;
  }
  .col-md-offset-2 {
    margin-left: 16.66666667%;
  }
  .col-md-offset-1 {
    margin-left: 8.33333333%;
  }
  .col-md-offset-0 {
    margin-left: 0%;
  }
}
@media (min-width: 1200px) {
  .col-lg-1,
  .col-lg-2,
  .col-lg-3,
  .col-lg-4,
  .col-lg-5,
  .col-lg-6,
  .col-lg-7,
  .col-lg-8,
  .col-lg-9,
  .col-lg-10,
  .col-lg-11,
  .col-lg-12 {
    float: left;
  }
  .col-lg-12 {
    width: 100%;
  }
  .col-lg-11 {
    width: 91.66666667%;
  }
  .col-lg-10 {
    width: 83.33333333%;
  }
  .col-lg-9 {
    width: 75%;
  }
  .col-lg-8 {
    width: 66.66666667%;
  }
  .col-lg-7 {
    width: 58.33333333%;
  }
  .col-lg-6 {
    width: 50%;
  }
  .col-lg-5 {
    width: 41.66666667%;
  }
  .col-lg-4 {
    width: 33.33333333%;
  }
  .col-lg-3 {
    width: 25%;
  }
  .col-lg-2 {
    width: 16.66666667%;
  }
  .col-lg-1 {
    width: 8.33333333%;
  }
  .col-lg-pull-12 {
    right: 100%;
  }
  .col-lg-pull-11 {
    right: 91.66666667%;
  }
  .col-lg-pull-10 {
    right: 83.33333333%;
  }
  .col-lg-pull-9 {
    right: 75%;
  }
  .col-lg-pull-8 {
    right: 66.66666667%;
  }
  .col-lg-pull-7 {
    right: 58.33333333%;
  }
  .col-lg-pull-6 {
    right: 50%;
  }
  .col-lg-pull-5 {
    right: 41.66666667%;
  }
  .col-lg-pull-4 {
    right: 33.33333333%;
  }
  .col-lg-pull-3 {
    right: 25%;
  }
  .col-lg-pull-2 {
    right: 16.66666667%;
  }
  .col-lg-pull-1 {
    right: 8.33333333%;
  }
  .col-lg-pull-0 {
    right: auto;
  }
  .col-lg-push-12 {
    left: 100%;
  }
  .col-lg-push-11 {
    left: 91.66666667%;
  }
  .col-lg-push-10 {
    left: 83.33333333%;
  }
  .col-lg-push-9 {
    left: 75%;
  }
  .col-lg-push-8 {
    left: 66.66666667%;
  }
  .col-lg-push-7 {
    left: 58.33333333%;
  }
  .col-lg-push-6 {
    left: 50%;
  }
  .col-lg-push-5 {
    left: 41.66666667%;
  }
  .col-lg-push-4 {
    left: 33.33333333%;
  }
  .col-lg-push-3 {
    left: 25%;
  }
  .col-lg-push-2 {
    left: 16.66666667%;
  }
  .col-lg-push-1 {
    left: 8.33333333%;
  }
  .col-lg-push-0 {
    left: auto;
  }
  .col-lg-offset-12 {
    margin-left: 100%;
  }
  .col-lg-offset-11 {
    margin-left: 91.66666667%;
  }
  .col-lg-offset-10 {
    margin-left: 83.33333333%;
  }
  .col-lg-offset-9 {
    margin-left: 75%;
  }
  .col-lg-offset-8 {
    margin-left: 66.66666667%;
  }
  .col-lg-offset-7 {
    margin-left: 58.33333333%;
  }
  .col-lg-offset-6 {
    margin-left: 50%;
  }
  .col-lg-offset-5 {
    margin-left: 41.66666667%;
  }
  .col-lg-offset-4 {
    margin-left: 33.33333333%;
  }
  .col-lg-offset-3 {
    margin-left: 25%;
  }
  .col-lg-offset-2 {
    margin-left: 16.66666667%;
  }
  .col-lg-offset-1 {
    margin-left: 8.33333333%;
  }
  .col-lg-offset-0 {
    margin-left: 0%;
  }
}
table {
  background-color: transparent;
}
caption {
  padding-top: 8px;
  padding-bottom: 8px;
  color: #777777;
  text-align: left;
}
th {
  text-align: left;
}
.table {
  width: 100%;
  max-width: 100%;
  margin-bottom: 20px;
}
.table > thead > tr > th,
.table > tbody > tr > th,
.table > tfoot > tr > th,
.table > thead > tr > td,
.table > tbody > tr > td,
.table > tfoot > tr > td {
  padding: 8px;
  line-height: 1.42857143;
  vertical-align: top;
  border-top: 1px solid #ddd;
}
.table > thead > tr > th {
  vertical-align: bottom;
  border-bottom: 2px solid #ddd;
}
.table > caption + thead > tr:first-child > th,
.table > colgroup + thead > tr:first-child > th,
.table > thead:first-child > tr:first-child > th,
.table > caption + thead > tr:first-child > td,
.table > colgroup + thead > tr:first-child > td,
.table > thead:first-child > tr:first-child > td {
  border-top: 0;
}
.table > tbody + tbody {
  border-top: 2px solid #ddd;
}
.table .table {
  background-color: #fff;
}
.table-condensed > thead > tr > th,
.table-condensed > tbody > tr > th,
.table-condensed > tfoot > tr > th,
.table-condensed > thead > tr > td,
.table-condensed > tbody > tr > td,
.table-condensed > tfoot > tr > td {
  padding: 5px;
}
.table-bordered {
  border: 1px solid #ddd;
}
.table-bordered > thead > tr > th,
.table-bordered > tbody > tr > th,
.table-bordered > tfoot > tr > th,
.table-bordered > thead > tr > td,
.table-bordered > tbody > tr > td,
.table-bordered > tfoot > tr > td {
  border: 1px solid #ddd;
}
.table-bordered > thead > tr > th,
.table-bordered > thead > tr > td {
  border-bottom-width: 2px;
}
.table-striped > tbody > tr:nth-of-type(odd) {
  background-color: #f9f9f9;
}
.table-hover > tbody > tr:hover {
  background-color: #f5f5f5;
}
table col[class*="col-"] {
  position: static;
  float: none;
  display: table-column;
}
table td[class*="col-"],
table th[class*="col-"] {
  position: static;
  float: none;
  display: table-cell;
}
.table > thead > tr > td.active,
.table > tbody > tr > td.active,
.table > tfoot > tr > td.active,
.table > thead > tr > th.active,
.table > tbody > tr > th.active,
.table > tfoot > tr > th.active,
.table > thead > tr.active > td,
.table > tbody > tr.active > td,
.table > tfoot > tr.active > td,
.table > thead > tr.active > th,
.table > tbody > tr.active > th,
.table > tfoot > tr.active > th {
  background-color: #f5f5f5;
}
.table-hover > tbody > tr > td.active:hover,
.table-hover > tbody > tr > th.active:hover,
.table-hover > tbody > tr.active:hover > td,
.table-hover > tbody > tr:hover > .active,
.table-hover > tbody > tr.active:hover > th {
  background-color: #e8e8e8;
}
.table > thead > tr > td.success,
.table > tbody > tr > td.success,
.table > tfoot > tr > td.success,
.table > thead > tr > th.success,
.table > tbody > tr > th.success,
.table > tfoot > tr > th.success,
.table > thead > tr.success > td,
.table > tbody > tr.success > td,
.table > tfoot > tr.success > td,
.table > thead > tr.success > th,
.table > tbody > tr.success > th,
.table > tfoot > tr.success > th {
  background-color: #dff0d8;
}
.table-hover > tbody > tr > td.success:hover,
.table-hover > tbody > tr > th.success:hover,
.table-hover > tbody > tr.success:hover > td,
.table-hover > tbody > tr:hover > .success,
.table-hover > tbody > tr.success:hover > th {
  background-color: #d0e9c6;
}
.table > thead > tr > td.info,
.table > tbody > tr > td.info,
.table > tfoot > tr > td.info,
.table > thead > tr > th.info,
.table > tbody > tr > th.info,
.table > tfoot > tr > th.info,
.table > thead > tr.info > td,
.table > tbody > tr.info > td,
.table > tfoot > tr.info > td,
.table > thead > tr.info > th,
.table > tbody > tr.info > th,
.table > tfoot > tr.info > th {
  background-color: #d9edf7;
}
.table-hover > tbody > tr > td.info:hover,
.table-hover > tbody > tr > th.info:hover,
.table-hover > tbody > tr.info:hover > td,
.table-hover > tbody > tr:hover > .info,
.table-hover > tbody > tr.info:hover > th {
  background-color: #c4e3f3;
}
.table > thead > tr > td.warning,
.table > tbody > tr > td.warning,
.table > tfoot > tr > td.warning,
.table > thead > tr > th.warning,
.table > tbody > tr > th.warning,
.table > tfoot > tr > th.warning,
.table > thead > tr.warning > td,
.table > tbody > tr.warning > td,
.table > tfoot > tr.warning > td,
.table > thead > tr.warning > th,
.table > tbody > tr.warning > th,
.table > tfoot > tr.warning > th {
  background-color: #fcf8e3;
}
.table-hover > tbody > tr > td.warning:hover,
.table-hover > tbody > tr > th.warning:hover,
.table-hover > tbody > tr.warning:hover > td,
.table-hover > tbody > tr:hover > .warning,
.table-hover > tbody > tr.warning:hover > th {
  background-color: #faf2cc;
}
.table > thead > tr > td.danger,
.table > tbody > tr > td.danger,
.table > tfoot > tr > td.danger,
.table > thead > tr > th.danger,
.table > tbody > tr > th.danger,
.table > tfoot > tr > th.danger,
.table > thead > tr.danger > td,
.table > tbody > tr.danger > td,
.table > tfoot > tr.danger > td,
.table > thead > tr.danger > th,
.table > tbody > tr.danger > th,
.table > tfoot > tr.danger > th {
  background-color: #f2dede;
}
.table-hover > tbody > tr > td.danger:hover,
.table-hover > tbody > tr > th.danger:hover,
.table-hover > tbody > tr.danger:hover > td,
.table-hover > tbody > tr:hover > .danger,
.table-hover > tbody > tr.danger:hover > th {
  background-color: #ebcccc;
}
.table-responsive {
  overflow-x: auto;
  min-height: 0.01%;
}
@media screen and (max-width: 767px) {
  .table-responsive {
    width: 100%;
    margin-bottom: 15px;
    overflow-y: hidden;
    -ms-overflow-style: -ms-autohiding-scrollbar;
    border: 1px solid #ddd;
  }
  .table-responsive > .table {
    margin-bottom: 0;
  }
  .table-responsive > .table > thead > tr > th,
  .table-responsive > .table > tbody > tr > th,
  .table-responsive > .table > tfoot > tr > th,
  .table-responsive > .table > thead > tr > td,
  .table-responsive > .table > tbody > tr > td,
  .table-responsive > .table > tfoot > tr > td {
    white-space: nowrap;
  }
  .table-responsive > .table-bordered {
    border: 0;
  }
  .table-responsive > .table-bordered > thead > tr > th:first-child,
  .table-responsive > .table-bordered > tbody > tr > th:first-child,
  .table-responsive > .table-bordered > tfoot > tr > th:first-child,
  .table-responsive > .table-bordered > thead > tr > td:first-child,
  .table-responsive > .table-bordered > tbody > tr > td:first-child,
  .table-responsive > .table-bordered > tfoot > tr > td:first-child {
    border-left: 0;
  }
  .table-responsive > .table-bordered > thead > tr > th:last-child,
  .table-responsive > .table-bordered > tbody > tr > th:last-child,
  .table-responsive > .table-bordered > tfoot > tr > th:last-child,
  .table-responsive > .table-bordered > thead > tr > td:last-child,
  .table-responsive > .table-bordered > tbody > tr > td:last-child,
  .table-responsive > .table-bordered > tfoot > tr > td:last-child {
    border-right: 0;
  }
  .table-responsive > .table-bordered > tbody > tr:last-child > th,
  .table-responsive > .table-bordered > tfoot > tr:last-child > th,
  .table-responsive > .table-bordered > tbody > tr:last-child > td,
  .table-responsive > .table-bordered > tfoot > tr:last-child > td {
    border-bottom: 0;
  }
}
.fade {
  opacity: 0;
  -webkit-transition: opacity 0.15s linear;
  -o-transition: opacity 0.15s linear;
  transition: opacity 0.15s linear;
}
.fade.in {
  opacity: 1;
}
.collapse {
  display: none;
}
.collapse.in {
  display: block;
}
tr.collapse.in {
  display: table-row;
}
tbody.collapse.in {
  display: table-row-group;
}
.collapsing {
  position: relative;
  height: 0;
  overflow: hidden;
  -webkit-transition-property: height, visibility;
  transition-property: height, visibility;
  -webkit-transition-duration: 0.35s;
  transition-duration: 0.35s;
  -webkit-transition-timing-function: ease;
  transition-timing-function: ease;
}
.caret {
  display: inline-block;
  width: 0;
  height: 0;
  margin-left: 2px;
  vertical-align: middle;
  border-top: 4px dashed;
  border-top: 4px solid \9;
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.dropup,
.dropdown {
  position: relative;
}
.dropdown-toggle:focus {
  outline: 0;
}
.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 160px;
  padding: 5px 0;
  margin: 2px 0 0;
  list-style: none;
  font-size: 14px;
  text-align: left;
  background-color: #fff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 4px;
  -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  background-clip: padding-box;
}
.dropdown-menu.pull-right {
  right: 0;
  left: auto;
}
.dropdown-menu .divider {
  height: 1px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5;
}
.dropdown-menu > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 1.42857143;
  color: #333333;
  white-space: nowrap;
}
.dropdown-menu > li > a:hover,
.dropdown-menu > li > a:focus {
  text-decoration: none;
  color: #262626;
  background-color: #f5f5f5;
}
.dropdown-menu > .active > a,
.dropdown-menu > .active > a:hover,
.dropdown-menu > .active > a:focus {
  color: #fff;
  text-decoration: none;
  outline: 0;
  background-color: #337ab7;
}
.dropdown-menu > .disabled > a,
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  color: #777777;
}
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  text-decoration: none;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  cursor: not-allowed;
}
.open > .dropdown-menu {
  display: block;
}
.open > a {
  outline: 0;
}
.dropdown-menu-right {
  left: auto;
  right: 0;
}
.dropdown-menu-left {
  left: 0;
  right: auto;
}
.dropdown-header {
  display: block;
  padding: 3px 20px;
  font-size: 12px;
  line-height: 1.42857143;
  color: #777777;
  white-space: nowrap;
}
.dropdown-backdrop {
  position: fixed;
  left: 0;
  right: 0;
  bottom: 0;
  top: 0;
  z-index: 990;
}
.pull-right > .dropdown-menu {
  right: 0;
  left: auto;
}
.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
  border-top: 0;
  border-bottom: 4px dashed;
  border-bottom: 4px solid \9;
  content: "";
}
.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
  top: auto;
  bottom: 100%;
  margin-bottom: 2px;
}
@media (min-width: 768px) {
  .navbar-right .dropdown-menu {
    left: auto;
    right: 0;
  }
  .navbar-right .dropdown-menu-left {
    left: 0;
    right: auto;
  }
}
.nav {
  margin-bottom: 0;
  padding-left: 0;
  list-style: none;
}
.nav > li {
  position: relative;
  display: block;
}
.nav > li > a {
  position: relative;
  display: block;
  padding: 10px 15px;
}
.nav > li > a:hover,
.nav > li > a:focus {
  text-decoration: none;
  background-color: #eeeeee;
}
.nav > li.disabled > a {
  color: #777777;
}
.nav > li.disabled > a:hover,
.nav > li.disabled > a:focus {
  color: #777777;
  text-decoration: none;
  background-color: transparent;
  cursor: not-allowed;
}
.nav .open > a,
.nav .open > a:hover,
.nav .open > a:focus {
  background-color: #eeeeee;
  border-color: #337ab7;
}
.nav .nav-divider {
  height: 1px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5;
}
.nav > li > a > img {
  max-width: none;
}
.nav-tabs {
  border-bottom: 1px solid #ddd;
}
.nav-tabs > li {
  float: left;
  margin-bottom: -1px;
}
.nav-tabs > li > a {
  margin-right: 2px;
  line-height: 1.42857143;
  border: 1px solid transparent;
  border-radius: 4px 4px 0 0;
}
.nav-tabs > li > a:hover {
  border-color: #eeeeee #eeeeee #ddd;
}
.nav-tabs > li.active > a,
.nav-tabs > li.active > a:hover,
.nav-tabs > li.active > a:focus {
  color: #555555;
  background-color: #fff;
  border: 1px solid #ddd;
  border-bottom-color: transparent;
  cursor: default;
}
.nav-tabs.nav-justified {
  width: 100%;
  border-bottom: 0;
}
.nav-tabs.nav-justified > li {
  float: none;
}
.nav-tabs.nav-justified > li > a {
  text-align: center;
  margin-bottom: 5px;
}
.nav-tabs.nav-justified > .dropdown .dropdown-menu {
  top: auto;
  left: auto;
}
@media (min-width: 768px) {
  .nav-tabs.nav-justified > li {
    display: table-cell;
    width: 1%;
  }
  .nav-tabs.nav-justified > li > a {
    margin-bottom: 0;
  }
}
.nav-tabs.nav-justified > li > a {
  margin-right: 0;
  border-radius: 4px;
}
.nav-tabs.nav-justified > .active > a,
.nav-tabs.nav-justified > .active > a:hover,
.nav-tabs.nav-justified > .active > a:focus {
  border: 1px solid #ddd;
}
@media (min-width: 768px) {
  .nav-tabs.nav-justified > li > a {
    border-bottom: 1px solid #ddd;
    border-radius: 4px 4px 0 0;
  }
  .nav-tabs.nav-justified > .active > a,
  .nav-tabs.nav-justified > .active > a:hover,
  .nav-tabs.nav-justified > .active > a:focus {
    border-bottom-color: #fff;
  }
}
.nav-pills > li {
  float: left;
}
.nav-pills > li > a {
  border-radius: 4px;
}
.nav-pills > li + li {
  margin-left: 2px;
}
.nav-pills > li.active > a,
.nav-pills > li.active > a:hover,
.nav-pills > li.active > a:focus {
  color: #fff;
  background-color: #337ab7;
}
.nav-stacked > li {
  float: none;
}
.nav-stacked > li + li {
  margin-top: 2px;
  margin-left: 0;
}
.nav-justified {
  width: 100%;
}
.nav-justified > li {
  float: none;
}
.nav-justified > li > a {
  text-align: center;
  margin-bottom: 5px;
}
.nav-justified > .dropdown .dropdown-menu {
  top: auto;
  left: auto;
}
@media (min-width: 768px) {
  .nav-justified > li {
    display: table-cell;
    width: 1%;
  }
  .nav-justified > li > a {
    margin-bottom: 0;
  }
}
.nav-tabs-justified {
  border-bottom: 0;
}
.nav-tabs-justified > li > a {
  margin-right: 0;
  border-radius: 4px;
}
.nav-tabs-justified > .active > a,
.nav-tabs-justified > .active > a:hover,
.nav-tabs-justified > .active > a:focus {
  border: 1px solid #ddd;
}
@media (min-width: 768px) {
  .nav-tabs-justified > li > a {
    border-bottom: 1px solid #ddd;
    border-radius: 4px 4px 0 0;
  }
  .nav-tabs-justified > .active > a,
  .nav-tabs-justified > .active > a:hover,
  .nav-tabs-justified > .active > a:focus {
    border-bottom-color: #fff;
  }
}
.tab-content > .tab-pane {
  display: none;
}
.tab-content > .active {
  display: block;
}
.nav-tabs .dropdown-menu {
  margin-top: -1px;
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}
.well {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #e3e3e3;
  border-radius: 4px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
}
.well blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}
.well-lg {
  padding: 24px;
  border-radius: 6px;
}
.well-sm {
  padding: 9px;
  border-radius: 3px;
}
.clearfix:before,
.clearfix:after,
.container:before,
.container:after,
.container-fluid:before,
.container-fluid:after,
.row:before,
.row:after,
.nav:before,
.nav:after,
.btn-toolbar:before,
.btn-toolbar:after {
  content: " ";
  display: table;
}
.clearfix:after,
.container:after,
.container-fluid:after,
.row:after,
.nav:after,
.btn-toolbar:after {
  clear: both;
}
.center-block {
  display: block;
  margin-left: auto;
  margin-right: auto;
}
.pull-right {
  float: right !important;
}
.pull-left {
  float: left !important;
}
.hide {
  display: none !important;
}
.show {
  display: block !important;
}
.invisible {
  visibility: hidden;
}
.text-hide {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
}
.hidden {
  display: none !important;
}
.affix {
  position: fixed;
}
@-ms-viewport {
  width: device-width;
}
.visible-xs,
.visible-sm,
.visible-md,
.visible-lg {
  display: none !important;
}
.visible-xs-block,
.visible-xs-inline,
.visible-xs-inline-block,
.visible-sm-block,
.visible-sm-inline,
.visible-sm-inline-block,
.visible-md-block,
.visible-md-inline,
.visible-md-inline-block,
.visible-lg-block,
.visible-lg-inline,
.visible-lg-inline-block {
  display: none !important;
}
@media (max-width: 767px) {
  .visible-xs {
    display: block !important;
  }
  table.visible-xs {
    display: table !important;
  }
  tr.visible-xs {
    display: table-row !important;
  }
  th.visible-xs,
  td.visible-xs {
    display: table-cell !important;
  }
}
@media (max-width: 767px) {
  .visible-xs-block {
    display: block !important;
  }
}
@media (max-width: 767px) {
  .visible-xs-inline {
    display: inline !important;
  }
}
@media (max-width: 767px) {
  .visible-xs-inline-block {
    display: inline-block !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm {
    display: block !important;
  }
  table.visible-sm {
    display: table !important;
  }
  tr.visible-sm {
    display: table-row !important;
  }
  th.visible-sm,
  td.visible-sm {
    display: table-cell !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm-block {
    display: block !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm-inline {
    display: inline !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .visible-sm-inline-block {
    display: inline-block !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md {
    display: block !important;
  }
  table.visible-md {
    display: table !important;
  }
  tr.visible-md {
    display: table-row !important;
  }
  th.visible-md,
  td.visible-md {
    display: table-cell !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md-block {
    display: block !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md-inline {
    display: inline !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .visible-md-inline-block {
    display: inline-block !important;
  }
}
@media (min-width: 1200px) {
  .visible-lg {
    display: block !important;
  }
  table.visible-lg {
    display: table !important;
  }
  tr.visible-lg {
    display: table-row !important;
  }
  th.visible-lg,
  td.visible-lg {
    display: table-cell !important;
  }
}
@media (min-width: 1200px) {
  .visible-lg-block {
    display: block !important;
  }
}
@media (min-width: 1200px) {
  .visible-lg-inline {
    display: inline !important;
  }
}
@media (min-width: 1200px) {
  .visible-lg-inline-block {
    display: inline-block !important;
  }
}
@media (max-width: 767px) {
  .hidden-xs {
    display: none !important;
  }
}
@media (min-width: 768px) and (max-width: 991px) {
  .hidden-sm {
    display: none !important;
  }
}
@media (min-width: 992px) and (max-width: 1199px) {
  .hidden-md {
    display: none !important;
  }
}
@media (min-width: 1200px) {
  .hidden-lg {
    display: none !important;
  }
}
.visible-print {
  display: none !important;
}
@media print {
  .visible-print {
    display: block !important;
  }
  table.visible-print {
    display: table !important;
  }
  tr.visible-print {
    display: table-row !important;
  }
  th.visible-print,
  td.visible-print {
    display: table-cell !important;
  }
}
.visible-print-block {
  display: none !important;
}
@media print {
  .visible-print-block {
    display: block !important;
  }
}
.visible-print-inline {
  display: none !important;
}
@media print {
  .visible-print-inline {
    display: inline !important;
  }
}
.visible-print-inline-block {
  display: none !important;
}
@media print {
  .visible-print-inline-block {
    display: inline-block !important;
  }
}
@media print {
  .hidden-print {
    display: none !important;
  }
}
/* additional styles for alert content. Used by both public side and dashboard */
.alert {
  margin-top: 20px;
}
.alert .close {
  position: relative;
  z-index: 5;
}
.alert .alertinner {
  position: relative;
}
.alert .alertinner.wicon {
  padding-left: 0.5em;
  margin-left: 0.5em;
}
.alert .alertinner [class*="icon-"] {
  position: absolute;
  top: 0.3em;
  right: 100%;
}
.alert .alertinner p {
  margin: 10px 0 0 0;
}
.alert .alertinner p:first-child {
  margin: 0;
}
h3.app-ico:before {
  display: none;
}
.no-float {
  float: none;
}
.tabbable.dashboard {
  margin-bottom: 1.42857143;
}
.tabbable.dashboard .navbar,
.tabbable.dashboard .nav-tabs {
  margin-bottom: 0;
}
.tabbable.dashboard .tab-content {
  display: block;
  width: auto;
  border: 1px #e1e1e1 solid;
  border-top-width: 0;
  padding: 30px;
}
.well,
.alert,
.table-bordered {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.well {
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.01);
  border-color: rgba(0, 0, 0, 0.04);
}
.well:before,
.well:after {
  content: " ";
  display: table;
}
.well:after {
  clear: both;
}
.well:before,
.well:after {
  content: " ";
  display: table;
}
.well:after {
  clear: both;
}
.well-success {
  background-color: #dff0d8;
  border-color: #d6e9c6;
}
.well-danger {
  background-color: #f2dede;
  border-color: #ebccd1;
}
.well-info {
  background-color: #d9edf7;
  border-color: #bce8f1;
}
.well-blank {
  background-color: #fff;
  border-color: rgba(0, 0, 0, 0.1);
}
.well-stacked .well {
  margin-bottom: 0;
  border-top-width: 0;
}
.well-stacked .well:first-child {
  border-top-width: 1px;
}
.create-page .well,
.promotions .well-info {
  background-color: #fff;
}
.alert-message.block-message.file_upload p {
  margin-right: 10px;
}
.modal > form {
  margin-bottom: 0;
}
div[data-spy="affix"] {
  width: 266px;
}
div[data-spy="affix"].affix {
  top: 1.42857143;
}
.bs-docs-sidenav {
  padding: 0;
  background-color: #fff;
  -webkit-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  -moz-box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
  box-shadow: 0 1px 4px rgba(0, 0, 0, 0.065);
}
.bs-docs-sidenav > li > a,
.bs-docs-sidenav > li > span {
  display: block;
  margin: 0;
  padding: 8px 14px;
  border: 1px solid #e5e5e5;
  border-top-width: 0;
  color: #337ab7;
}
.bs-docs-sidenav > li > a:hover,
.bs-docs-sidenav > li > span:hover {
  background: #f1faff;
}
.bs-docs-sidenav > li > a i.icon-info-sign,
.bs-docs-sidenav > li > span i.icon-info-sign {
  color: #ea0001;
  font-size: 16px;
}
.bs-docs-sidenav > li > span {
  color: #333;
}
.bs-docs-sidenav > .active > a,
.bs-docs-sidenav > .active > span {
  font-weight: bold;
  position: relative;
  color: #337ab7;
  background: #f1faff;
  z-index: 2;
  padding: 9px 15px;
  text-shadow: 0 1px 0 rgba(0, 0, 0, 0.15);
}
.bs-docs-sidenav > .active > a:hover,
.bs-docs-sidenav > .active > span:hover {
  background: #f1faff;
  color: #337ab7;
}
.bs-docs-sidenav > .active > a:after,
.bs-docs-sidenav > .active > span:after {
  border-bottom: 10px solid transparent;
  border-left: 10px solid #f1faff;
  border-top: 10px solid transparent;
  content: "";
  display: inline-block;
  position: absolute;
  right: -9px;
  top: 9px;
}
.bs-docs-sidenav > .active > a:before,
.bs-docs-sidenav > .active > span:before {
  border-bottom: 11px solid transparent;
  border-left: 11px solid #ccc;
  border-top: 11px solid transparent;
  content: "";
  display: inline-block;
  position: absolute;
  right: -10px;
  top: 8px;
}
@media (max-width: 1300px) {
  div[data-spy="affix"] {
    width: 200px;
  }
  .navbar-primary .nav > li a:before {
    display: none;
  }
  table .btn {
    padding: 3px 9px;
    font-size: 12px;
    line-height: -0.57142857px;
  }
}
@media (max-width: 979px) {
  .affix {
    position: static;
  }
  div[data-spy="affix"] {
    width: 100%;
    margin-bottom: 1.42857143;
  }
  .navbar-primary .nav > li > a {
    border: 0;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    border-radius: 4px;
  }
  .navbar-primary .nav > li > a:hover {
    background: #222;
  }
}
body.oscar header {
  margin-bottom: 0;
}
.oscar.breadcrumbs {
  margin-bottom: 2em;
}
.oscar .multiple {
  overflow: inherit;
}
.in_popup .nav-wrapper {
  display: none;
}
.wrapper > .in_popup {
  margin-left: -180px;
}
.oscar #order_lines_form .listing input {
  padding: 4px;
}
.oscar .listing .actions {
  visibility: inherit;
}
code {
  text-transform: none;
}
.btn-toolbar {
  margin-left: -16px;
}
.btn-toolbar .btn,
.btn-toolbar .btn-group,
.btn-toolbar .input-group {
  float: left;
}
.btn-toolbar > .btn,
.btn-toolbar > .btn-group,
.btn-toolbar > .input-group {
  margin-left: 16px;
}
.datetimepicker .glyphicon {
  font-family: OscarFontAwesome;
  font-weight: normal;
  font-style: normal;
  text-decoration: inherit;
  -webkit-font-smoothing: antialiased;
  *margin-right: 0.3em;
}
.form-inline .form-group .form-inline {
  display: inline-block;
}
.dropdown-menu {
  top: auto;
}
.dropdown-menu.pull-right {
  right: auto;
}
.navbar {
  margin-bottom: 0;
}
.navbar .nav > li span {
  display: block;
  padding: 14px;
}
.dropdown-menu {
  font-size: 12px;
}
.navbar-inverse {
  color: #DCDCDC;
}
.navbar-accounts .container-fluid {
  max-width: 100%;
  padding-left: 20px;
  padding-right: 20px;
  min-height: 50px;
  font-size: 12px;
  line-height: 1.6666;
  background-image: -webkit-linear-gradient(top, #373737 0%, #242424 100%);
  background-image: -o-linear-gradient(top, #373737 0%, #242424 100%);
  background-image: linear-gradient(to bottom, #373737 0%, #242424 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff373737', endColorstr='#ff242424', GradientType=0);
  border: none;
}
.navbar-accounts .container-fluid .navbar-brand {
  background: transparent;
  text-indent: -9999px;
  display: block;
  width: 60px;
  height: 38px;
  padding: 0;
  margin-left: 0;
  margin-top: 5px;
}
.navbar-accounts .container-fluid .navbar-nav {
  top: 5px;
}
.navbar-accounts .container-fluid .navbar-nav > li > a {
  color: #C1C1C1;
}
.navbar-primary {
  min-height: 44px;
}
.navbar-primary .container-fluid {
  background-image: -webkit-linear-gradient(top, #353535 0%, #373737 100%);
  background-image: -o-linear-gradient(top, #353535 0%, #373737 100%);
  background-image: linear-gradient(to bottom, #353535 0%, #373737 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff353535', endColorstr='#ff373737', GradientType=0);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false) !important;
  border-top: 1px solid #5B5B5B;
  *position: relative;
  *z-index: 10;
}
.navbar-primary .nav.open .dropdown-toggle {
  border-color: #444;
  border-right-color: #222;
}
.navbar-primary .nav > li > a {
  margin: 0;
  border-left: 1px solid #444;
  border-right: 1px solid #222222;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
  color: #DCDCDC;
  font-size: 12px;
  line-height: 1.2;
  padding: 15px;
}
.navbar-primary .nav > li > a .caret {
  border-top-color: #DCDCDC;
  border-bottom-color: #DCDCDC;
  margin-top: 4px;
}
.navbar-primary .nav > li > a:hover .caret {
  border-top-color: #B2DEF2;
  border-bottom-color: #B2DEF2;
}
.navbar-primary .nav > li i {
  color: #dcdcdc;
  padding-right: 12px;
}
.navbar-primary .nav > li .dropdown-menu {
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.navbar-primary .nav > .active > a,
.navbar-primary .nav > .active > a:hover,
.navbar-primary .nav > li > a:hover,
.navbar-primary .nav .open .dropdown-toggle {
  color: #B2DEF2;
  background-color: #373737;
  border-left: 1px solid #444;
  border-right-color: #222222;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.05);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.05);
  background-image: -webkit-linear-gradient(top, #1F1F1F 0%, #373737 100%);
  background-image: -o-linear-gradient(top, #1F1F1F 0%, #373737 100%);
  background-image: linear-gradient(to bottom, #1F1F1F 0%, #373737 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff1f1f1f', endColorstr='#ff373737', GradientType=0);
}
.navbar-primary .nav > .active > a:before,
.navbar-primary .nav > .active > a:hover:before,
.navbar-primary .nav > li > a:hover:before,
.navbar-primary .nav .open .dropdown-toggle:before {
  color: #B2DEF2;
}
form.flat {
  margin: 0;
}
.form-horizontal .control-label,
.form-stacked .control-label {
  text-align: left;
}
.form-horizontal .control-label.required:after,
.form-stacked .control-label.required:after {
  content: "*";
  display: inline;
}
.form-horizontal .control-group,
.form-stacked .control-group {
  margin-bottom: 0.71428571;
}
.form-horizontal input[type=text],
.form-stacked input[type=text],
.form-horizontal input[type=number],
.form-stacked input[type=number],
.form-horizontal input[type=email],
.form-stacked input[type=email],
.form-horizontal input[type=url],
.form-stacked input[type=url],
.form-horizontal textarea,
.form-stacked textarea,
.form-horizontal select,
.form-stacked select {
  font-size: 12px;
}
.form-horizontal textarea,
.form-stacked textarea {
  max-height: 200px;
}
.form-inline select {
  min-width: 200px;
}
.form-inline .select2-container.form-control {
  display: inline-block;
}
.form-inline .form-group .form-inline {
  display: inline-block;
}
.form-inline {
  margin-bottom: 0;
}
.form-inline .help-block:first-child,
.form-inline .error-block:first-child {
  display: none;
}
.form-inline label {
  margin-right: 5px;
}
.form-inline .control-group {
  margin-right: 10px;
}
.form-inline .product-select {
  width: 270px;
}
.create-page .form-horizontal input[type=text],
.create-page .form-stacked input[type=text],
.create-page .form-horizontal input[type=number],
.create-page .form-stacked input[type=number],
.create-page .form-horizontal input[type=email],
.create-page .form-stacked input[type=email],
.create-page .form-horizontal input[type=url],
.create-page .form-stacked input[type=url],
.create-page .form-horizontal textarea,
.create-page .form-stacked textarea {
  width: 95%;
}
.create-page .form-stacked .form-inline input[type=text],
.create-page .form-stacked .form-inline input[type=number],
.create-page .form-stacked .form-inline input[type=email],
.create-page .form-stacked .form-inline input[type=url],
.create-page .form-stacked .form-inline textarea {
  width: auto;
}
.create-page label {
  font-weight: bold;
}
.form-stacked .error-block {
  display: block;
  color: #b94a48;
}
form .form-group .form-inline .input-group.date input {
  width: 100%;
}
@media (min-width: 768px) {
  form .form-group .form-inline .input-group.date input {
    width: 145px;
  }
}
.fields-full input[type=text],
.fields-full textarea {
  width: 100%;
}
textarea.plain {
  font-family: monospace;
}
.well .form-actions,
.tabbable.dashboard .tab-content .form-actions {
  margin-bottom: 0;
  position: relative;
  bottom: -19px;
  left: -19px;
  width: 100%;
  padding: 19px;
  border-top-color: #ccc;
}
.tabbable.dashboard .tab-content .form-actions {
  bottom: -50px;
  left: -29px;
  padding-left: 29px;
  padding-right: 29px;
}
.wysihtml5-sandbox {
  border: 1px solid #ccc !important;
}
.wysihtml5-toolbar:before,
.wysihtml5-toolbar:after {
  content: " ";
  display: table;
}
.wysihtml5-toolbar:after {
  clear: both;
}
.wysihtml5-toolbar:before,
.wysihtml5-toolbar:after {
  content: " ";
  display: table;
}
.wysihtml5-toolbar:after {
  clear: both;
}
textarea {
  width: 500px;
  height: 400px;
}
/* ADDITIONAL ERRORS */
.errorlist {
  margin: 0 0 0 20px;
  padding: 0 0 10px 0;
  color: #B94A48;
}
.errorlist li {
  padding: 0 0 5px 0;
  list-style: none;
}
.form-inline .help-block,
.form-inline .error-block {
  display: inline-block;
  margin: 0 20px 0 10px;
}
.form-inline .help-block li,
.form-inline .error-block li {
  list-style: none;
  color: #B94A48;
}
.form-inline input[type=number],
.form-inline input[type=email],
.form-inline input[type=url],
.form-inline input[type=text] {
  width: 140px;
}
body.dashboard-login {
  padding-top: 60px;
  background-image: none;
  background-color: #f5f5f5;
}
body.dashboard-login h1 {
  text-align: center;
}
#order_graph {
  position: relative;
  margin-bottom: 5em;
  width: 99%;
  height: 330px;
}
#order_graph .bar-caption {
  position: relative;
  text-align: center;
  top: 0;
}
#order_graph .bar-caption h1 {
  font-size: 18px;
  color: #242424;
  font-weight: bold;
  text-transform: uppercase;
}
#order_graph .bar-y-axis {
  position: absolute;
  top: 16px;
  width: 5em;
  margin: 0;
  padding: 0;
  float: left;
  display: inline;
}
#order_graph .bar-y-axis li {
  list-style: none;
  height: 33px;
  float: right;
  color: #868686;
}
#order_graph .bar-chart,
#order_graph .bar-chart dt,
#order_graph .bar-chart dd {
  margin: 0;
  padding: 0;
}
#order_graph .bar-chart {
  position: absolute;
  top: 0;
  left: 0;
  width: 98%;
  height: 300px;
}
#order_graph .bar-chart dd {
  position: relative;
  float: left;
  width: 8%;
  height: 330px;
  margin-top: 22px;
}
#order_graph .bar-chart dd em {
  position: absolute;
  bottom: -2em;
  right: 0;
  font-style: inherit;
  color: #868686;
}
#order_graph .bar-chart span {
  position: absolute;
  display: block;
  width: 30%;
  bottom: 0;
  right: 0;
  z-index: 1;
  color: #555555;
  text-align: center;
  text-decoration: none;
}
#order_graph .bar-chart span p {
  position: relative;
  top: 1em;
  display: none;
  padding: 3px;
  color: #333333;
  z-index: 2;
  background-color: #fff;
  font-weight: bold;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
#order_graph .bar-chart span {
  height: 50%;
  background-image: -webkit-linear-gradient(top, #0e91bf 0%, #0b759b 100%);
  background-image: -o-linear-gradient(top, #0e91bf 0%, #0b759b 100%);
  background-image: linear-gradient(to bottom, #0e91bf 0%, #0b759b 100%);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff0e91bf', endColorstr='#ff0b759b', GradientType=0);
}
.order-graph-details label {
  cursor: default;
  background-color: #f8f8f8;
  border: 1px solid #ccc;
  display: block;
  margin-bottom: 15px;
  padding: 12px;
  color: #878787;
  font-size: 12px;
}
.order-graph-details label:before,
.order-graph-details label:after {
  content: " ";
  display: table;
}
.order-graph-details label:after {
  clear: both;
}
.order-graph-details label:before,
.order-graph-details label:after {
  content: " ";
  display: table;
}
.order-graph-details label:after {
  clear: both;
}
.order-graph-details label span {
  display: inline-block;
  font-weight: bold;
  width: 40%;
  font-size: 16px;
  color: #242424;
}
.order-graph-details label i {
  color: #0d84ae;
  margin-right: 5px;
  font-size: 18px;
}
.order-summary {
  padding: 0px;
  margin: 0px;
  background: #efefef;
}
.order-summary:before,
.order-summary:after {
  content: " ";
  display: table;
}
.order-summary:after {
  clear: both;
}
.order-summary:before,
.order-summary:after {
  content: " ";
  display: table;
}
.order-summary:after {
  clear: both;
}
.order-summary > li {
  list-style: none;
}
.order-summary li {
  float: left;
}
.order-summary li li {
  float: none;
}
.order-summary li {
  width: 20%;
  text-align: center;
}
.order-summary div {
  border-left: 1px solid #dcdcdc;
  padding: 20px 10px;
  min-height: 85px;
}
.order-summary strong {
  display: block;
  margin-top: 20px;
}
.order-summary li {
  width: 16%;
}
.order-summary li:first-child div {
  border-left: none;
}
.nav-main .oscar.menu-item a::before {
  font-size: 100%;
}
.oscar {
  overflow-x: hidden;
}
.oscar * {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.oscar *:before,
.oscar *:after {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.oscar .order-graph-details {
  padding-top: 15px;
}
.oscar .order-graph-details label {
  width: 100%;
}
.oscar #order_graph .bar-chart {
  margin-left: 30px;
}
header.oscar .breadcrumbs .breadcrumb {
  margin-top: -2em;
  margin-bottom: 1em;
}
.oscar label {
  width: auto;
}
.oscar label.radio-inline {
  width: auto;
  padding: 0;
  display: inline-flex;
}
.oscar .field-content label {
  padding-bottom: 0;
}
.oscar form .field > label {
  width: 16.6667%;
}
.oscar form .field label + div {
  float: left;
  width: calc(100% - 16.6667);
}
.oscar form .form-group {
  display: block;
  clear: both;
  margin-bottom: 8px;
}
.oscar form .form-group > div {
  min-height: 40px;
}
.oscar form .form-group + button {
  clear: both;
}
.oscar form.inline-form label {
  width: 100%;
}
.oscar input[type="radio"]::before {
  border: 0;
}
.oscar input[type="radio"],
.oscar input[type="checkbox"] {
  margin-right: 24px;
}
.oscar input[type="radio"]::before,
.oscar input[type="checkbox"]::before {
  top: -4px;
}
.oscar .listing tbody tr:first-child {
  border-top: 0;
}
.oscar .modal-dialog .modal-content {
  padding-left: 20px;
  padding-right: 20px;
}
@media screen and (min-width: 50em) {
  .oscar .modal-dialog .modal-content {
    padding-left: 50px;
    padding-right: 50px;
  }
}
.oscar .modal-dialog .close {
  width: 32px;
  height: 32px;
}
.oscar .form-group .mce-tinymce {
  clear: both;
}
.replace-file-input #fileupload {
  height: 100%;
}
#product_category select {
  width: 350px;
}
#product_stock table thead tr th {
  overflow: unset;
  white-space: unset;
  word-wrap: unset;
}
.catalogue .tab-content {
  overflow: visible;
}
.upload-image {
  margin: 0;
  z-index: 1;
  position: relative;
}
.upload-image:before,
.upload-image:after {
  content: " ";
  display: table;
}
.upload-image:after {
  clear: both;
}
.upload-image:before,
.upload-image:after {
  content: " ";
  display: table;
}
.upload-image:after {
  clear: both;
}
.upload-image li {
  display: block;
  width: 200px;
  margin: 0 1% 2%;
  float: left;
  text-align: center;
}
.upload-image li > div {
  padding: 4px;
  background: #ccc;
  margin-bottom: 10px;
}
.upload-image div {
  background: #fff;
  position: relative;
  width: 200px;
  height: 200px;
  z-index: 200;
}
.upload-image img {
  position: absolute;
  margin: auto;
  top: 0;
  max-height: 200px;
  max-width: 200px;
  width: auto;
  height: auto;
  left: 0;
}
.upload-image .image-input {
  z-index: 800;
}
.upload-image .image-input button {
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  -webkit-border-radius: 0;
  -moz-border-radius: 0;
  border-radius: 0;
}
.upload-image .input-field {
  position: relative;
  z-index: 1000;
  opacity: 0;
}
.upload-image .input-field input {
  border-width: 0;
  direction: ltr;
  cursor: pointer;
  width: 200px;
  height: 200px;
}
/*!
 *  Font Awesome 3.2.1
 *  the iconic font designed for Bootstrap
 *  ------------------------------------------------------------------------------
 *  The full suite of pictographic icons, examples, and documentation can be
 *  found at http://fontawesome.io.  Stay up to date on Twitter at
 *  http://twitter.com/fontawesome.
 *
 *  License
 *  ------------------------------------------------------------------------------
 *  - The Font Awesome font is licensed under SIL OFL 1.1 -
 *    http://scripts.sil.org/OFL
 *  - Font Awesome CSS, LESS, and SASS files are licensed under MIT License -
 *    http://opensource.org/licenses/mit-license.html
 *  - Font Awesome documentation licensed under CC BY 3.0 -
 *    http://creativecommons.org/licenses/by/3.0/
 *  - Attribution is no longer required in Font Awesome 3.0, but much appreciated:
 *    "Font Awesome by Dave Gandy - http://fontawesome.io"
 *
 *  Author - Dave Gandy
 *  ------------------------------------------------------------------------------
 *  Email: dave@fontawesome.io
 *  Twitter: http://twitter.com/davegandy
 *  Work: Lead Product Designer @ Kyruus - http://kyruus.com
 */
.oscar {
  /* FONT PATH
 * -------------------------- */
  /* FONT AWESOME CORE
 * -------------------------- */
  /* makes the font 33% larger relative to the icon container */
  /* makes sure icons active on rollover in links */
  /* increased font size for icon-large */
  /* BOOTSTRAP SPECIFIC CLASSES
 * -------------------------- */
  /* keeps Bootstrap styles with and without icons the same */
  /* EXTRAS
 * -------------------------- */
  /* Stacked and layered icon */
  /* Animated rotating icon */
  /* Prevent stack and spinners from being taken inline when inside a link */
  /* Icon rotations and mirroring */
  /* ensure rotation occurs inside anchor tags */
  /* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */
}
@font-face {
  font-family: "OscarFontAwesome";
  src: url("../fonts/fontawesome-webfont.eot?v=3.2.1");
  src: url("../fonts/fontawesome-webfont.eot?#iefix&v=3.2.1") format("embedded-opentype"), url("../fonts/fontawesome-webfont.woff?v=3.2.1") format("woff"), url("../fonts/fontawesome-webfont.ttf?v=3.2.1") format("truetype"), url("../fonts/fontawesome-webfont.svg#fontawesomeregular?v=3.2.1") format("svg");
  font-weight: normal;
  font-style: normal;
}
.oscar [class^="icon-"]:before,
.oscar [class*=" icon-"]:before {
  font-family: OscarFontAwesome;
  font-weight: normal;
  font-style: normal;
  -webkit-font-smoothing: antialiased;
  *margin-right: 0.3em;
  text-decoration: inherit;
  display: inline-block;
  speak: none;
}
.oscar .icon-large:before {
  vertical-align: -10%;
  font-size: 1.33333333em;
}
.oscar a [class^="icon-"],
.oscar a [class*=" icon-"] {
  display: inline;
}
.oscar [class^="icon-"].icon-fixed-width,
.oscar [class*=" icon-"].icon-fixed-width {
  display: inline-block;
  width: 1.14285714em;
  text-align: right;
  padding-right: 0.28571429em;
}
.oscar [class^="icon-"].icon-fixed-width.icon-large,
.oscar [class*=" icon-"].icon-fixed-width.icon-large {
  width: 1.42857143em;
}
.oscar .icons-ul {
  margin-left: 2.14285714em;
  list-style-type: none;
}
.oscar .icons-ul > li {
  position: relative;
}
.oscar .icons-ul .icon-li {
  position: absolute;
  left: -2.14285714em;
  width: 2.14285714em;
  text-align: center;
  line-height: inherit;
}
.oscar [class^="icon-"].hide,
.oscar [class*=" icon-"].hide {
  display: none;
}
.oscar .icon-muted {
  color: #eee;
}
.oscar .icon-light {
  color: #fff;
}
.oscar .icon-dark {
  color: #333;
}
.oscar .icon-border {
  border: solid 1px #eee;
  padding: 0.2em 0.25em 0.15em;
  -webkit-border-radius: 3px;
  -moz-border-radius: 3px;
  border-radius: 3px;
}
.oscar .icon-2x {
  font-size: 2em;
}
.oscar .icon-2x.icon-border {
  border-width: 2px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
  border-radius: 4px;
}
.oscar .icon-3x {
  font-size: 3em;
}
.oscar .icon-3x.icon-border {
  border-width: 3px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
.oscar .icon-4x {
  font-size: 4em;
}
.oscar .icon-4x.icon-border {
  border-width: 4px;
  -webkit-border-radius: 6px;
  -moz-border-radius: 6px;
  border-radius: 6px;
}
.oscar .icon-5x {
  font-size: 5em;
}
.oscar .icon-5x.icon-border {
  border-width: 5px;
  -webkit-border-radius: 7px;
  -moz-border-radius: 7px;
  border-radius: 7px;
}
.oscar .pull-right {
  float: right;
}
.oscar .pull-left {
  float: left;
}
.oscar [class^="icon-"].pull-left,
.oscar [class*=" icon-"].pull-left {
  margin-right: 0.3em;
}
.oscar [class^="icon-"].pull-right,
.oscar [class*=" icon-"].pull-right {
  margin-left: 0.3em;
}
.oscar .btn [class^="icon-"].icon-large,
.oscar .nav [class^="icon-"].icon-large,
.oscar .btn [class*=" icon-"].icon-large,
.oscar .nav [class*=" icon-"].icon-large {
  line-height: 0.9em;
}
.oscar .btn [class^="icon-"].icon-spin,
.oscar .nav [class^="icon-"].icon-spin,
.oscar .btn [class*=" icon-"].icon-spin,
.oscar .nav [class*=" icon-"].icon-spin {
  display: inline-block;
}
.oscar .nav-tabs [class^="icon-"],
.oscar .nav-pills [class^="icon-"],
.oscar .nav-tabs [class*=" icon-"],
.oscar .nav-pills [class*=" icon-"],
.oscar .nav-tabs [class^="icon-"].icon-large,
.oscar .nav-pills [class^="icon-"].icon-large,
.oscar .nav-tabs [class*=" icon-"].icon-large,
.oscar .nav-pills [class*=" icon-"].icon-large {
  line-height: 0.9em;
}
.oscar .btn [class^="icon-"].pull-left.icon-2x,
.oscar .btn [class*=" icon-"].pull-left.icon-2x,
.oscar .btn [class^="icon-"].pull-right.icon-2x,
.oscar .btn [class*=" icon-"].pull-right.icon-2x {
  margin-top: 0.18em;
}
.oscar .btn [class^="icon-"].icon-spin.icon-large,
.oscar .btn [class*=" icon-"].icon-spin.icon-large {
  line-height: 0.8em;
}
.oscar .btn.btn-small [class^="icon-"].pull-left.icon-2x,
.oscar .btn.btn-small [class*=" icon-"].pull-left.icon-2x,
.oscar .btn.btn-small [class^="icon-"].pull-right.icon-2x,
.oscar .btn.btn-small [class*=" icon-"].pull-right.icon-2x {
  margin-top: 0.25em;
}
.oscar .btn.btn-large [class^="icon-"],
.oscar .btn.btn-large [class*=" icon-"] {
  margin-top: 0;
}
.oscar .btn.btn-large [class^="icon-"].pull-left.icon-2x,
.oscar .btn.btn-large [class*=" icon-"].pull-left.icon-2x,
.oscar .btn.btn-large [class^="icon-"].pull-right.icon-2x,
.oscar .btn.btn-large [class*=" icon-"].pull-right.icon-2x {
  margin-top: 0.05em;
}
.oscar .btn.btn-large [class^="icon-"].pull-left.icon-2x,
.oscar .btn.btn-large [class*=" icon-"].pull-left.icon-2x {
  margin-right: 0.2em;
}
.oscar .btn.btn-large [class^="icon-"].pull-right.icon-2x,
.oscar .btn.btn-large [class*=" icon-"].pull-right.icon-2x {
  margin-left: 0.2em;
}
.oscar .icon-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: -35%;
}
.oscar .icon-stack [class^="icon-"],
.oscar .icon-stack [class*=" icon-"] {
  display: block;
  text-align: center;
  position: absolute;
  width: 100%;
  height: 100%;
  font-size: 1em;
  line-height: inherit;
  *line-height: 2em;
}
.oscar .icon-stack .icon-stack-base {
  font-size: 2em;
  *line-height: 1em;
}
.oscar .icon-spin {
  display: inline-block;
  -moz-animation: spin 2s infinite linear;
  -o-animation: spin 2s infinite linear;
  -webkit-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
}
.oscar a .icon-stack,
.oscar a .icon-spin {
  display: inline-block;
  text-decoration: none;
}
@-moz-keyframes spin {
  0% {
    -moz-transform: rotate(0deg);
  }
  100% {
    -moz-transform: rotate(359deg);
  }
}
@-webkit-keyframes spin {
  0% {
    -webkit-transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
  }
}
@-o-keyframes spin {
  0% {
    -o-transform: rotate(0deg);
  }
  100% {
    -o-transform: rotate(359deg);
  }
}
@-ms-keyframes spin {
  0% {
    -ms-transform: rotate(0deg);
  }
  100% {
    -ms-transform: rotate(359deg);
  }
}
@keyframes spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(359deg);
  }
}
.oscar .icon-rotate-90:before {
  -webkit-transform: rotate(90deg);
  -moz-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  -o-transform: rotate(90deg);
  transform: rotate(90deg);
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
}
.oscar .icon-rotate-180:before {
  -webkit-transform: rotate(180deg);
  -moz-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  -o-transform: rotate(180deg);
  transform: rotate(180deg);
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);
}
.oscar .icon-rotate-270:before {
  -webkit-transform: rotate(270deg);
  -moz-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  -o-transform: rotate(270deg);
  transform: rotate(270deg);
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3);
}
.oscar .icon-flip-horizontal:before {
  -webkit-transform: scale(-1, 1);
  -moz-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  -o-transform: scale(-1, 1);
  transform: scale(-1, 1);
}
.oscar .icon-flip-vertical:before {
  -webkit-transform: scale(1, -1);
  -moz-transform: scale(1, -1);
  -ms-transform: scale(1, -1);
  -o-transform: scale(1, -1);
  transform: scale(1, -1);
}
.oscar a .icon-rotate-90:before,
.oscar a .icon-rotate-180:before,
.oscar a .icon-rotate-270:before,
.oscar a .icon-flip-horizontal:before,
.oscar a .icon-flip-vertical:before {
  display: inline-block;
}
.oscar .icon-glass:before {
  content: "\f000";
}
.oscar .icon-music:before {
  content: "\f001";
}
.oscar .icon-search:before {
  content: "\f002";
}
.oscar .icon-envelope-alt:before {
  content: "\f003";
}
.oscar .icon-heart:before {
  content: "\f004";
}
.oscar .icon-star:before {
  content: "\f005";
}
.oscar .icon-star-empty:before {
  content: "\f006";
}
.oscar .icon-user:before {
  content: "\f007";
}
.oscar .icon-film:before {
  content: "\f008";
}
.oscar .icon-th-large:before {
  content: "\f009";
}
.oscar .icon-th:before {
  content: "\f00a";
}
.oscar .icon-th-list:before {
  content: "\f00b";
}
.oscar .icon-ok:before {
  content: "\f00c";
}
.oscar .icon-remove:before {
  content: "\f00d";
}
.oscar .icon-zoom-in:before {
  content: "\f00e";
}
.oscar .icon-zoom-out:before {
  content: "\f010";
}
.oscar .icon-power-off:before,
.oscar .icon-off:before {
  content: "\f011";
}
.oscar .icon-signal:before {
  content: "\f012";
}
.oscar .icon-gear:before,
.oscar .icon-cog:before {
  content: "\f013";
}
.oscar .icon-trash:before {
  content: "\f014";
}
.oscar .icon-home:before {
  content: "\f015";
}
.oscar .icon-file-alt:before {
  content: "\f016";
}
.oscar .icon-time:before {
  content: "\f017";
}
.oscar .icon-road:before {
  content: "\f018";
}
.oscar .icon-download-alt:before {
  content: "\f019";
}
.oscar .icon-download:before {
  content: "\f01a";
}
.oscar .icon-upload:before {
  content: "\f01b";
}
.oscar .icon-inbox:before {
  content: "\f01c";
}
.oscar .icon-play-circle:before {
  content: "\f01d";
}
.oscar .icon-rotate-right:before,
.oscar .icon-repeat:before {
  content: "\f01e";
}
.oscar .icon-refresh:before {
  content: "\f021";
}
.oscar .icon-list-alt:before {
  content: "\f022";
}
.oscar .icon-lock:before {
  content: "\f023";
}
.oscar .icon-flag:before {
  content: "\f024";
}
.oscar .icon-headphones:before {
  content: "\f025";
}
.oscar .icon-volume-off:before {
  content: "\f026";
}
.oscar .icon-volume-down:before {
  content: "\f027";
}
.oscar .icon-volume-up:before {
  content: "\f028";
}
.oscar .icon-qrcode:before {
  content: "\f029";
}
.oscar .icon-barcode:before {
  content: "\f02a";
}
.oscar .icon-tag:before {
  content: "\f02b";
}
.oscar .icon-tags:before {
  content: "\f02c";
}
.oscar .icon-book:before {
  content: "\f02d";
}
.oscar .icon-bookmark:before {
  content: "\f02e";
}
.oscar .icon-print:before {
  content: "\f02f";
}
.oscar .icon-camera:before {
  content: "\f030";
}
.oscar .icon-font:before {
  content: "\f031";
}
.oscar .icon-bold:before {
  content: "\f032";
}
.oscar .icon-italic:before {
  content: "\f033";
}
.oscar .icon-text-height:before {
  content: "\f034";
}
.oscar .icon-text-width:before {
  content: "\f035";
}
.oscar .icon-align-left:before {
  content: "\f036";
}
.oscar .icon-align-center:before {
  content: "\f037";
}
.oscar .icon-align-right:before {
  content: "\f038";
}
.oscar .icon-align-justify:before {
  content: "\f039";
}
.oscar .icon-list:before {
  content: "\f03a";
}
.oscar .icon-indent-left:before {
  content: "\f03b";
}
.oscar .icon-indent-right:before {
  content: "\f03c";
}
.oscar .icon-facetime-video:before {
  content: "\f03d";
}
.oscar .icon-picture:before {
  content: "\f03e";
}
.oscar .icon-pencil:before {
  content: "\f040";
}
.oscar .icon-map-marker:before {
  content: "\f041";
}
.oscar .icon-adjust:before {
  content: "\f042";
}
.oscar .icon-tint:before {
  content: "\f043";
}
.oscar .icon-edit:before {
  content: "\f044";
}
.oscar .icon-share:before {
  content: "\f045";
}
.oscar .icon-check:before {
  content: "\f046";
}
.oscar .icon-move:before {
  content: "\f047";
}
.oscar .icon-step-backward:before {
  content: "\f048";
}
.oscar .icon-fast-backward:before {
  content: "\f049";
}
.oscar .icon-backward:before {
  content: "\f04a";
}
.oscar .icon-play:before {
  content: "\f04b";
}
.oscar .icon-pause:before {
  content: "\f04c";
}
.oscar .icon-stop:before {
  content: "\f04d";
}
.oscar .icon-forward:before {
  content: "\f04e";
}
.oscar .icon-fast-forward:before {
  content: "\f050";
}
.oscar .icon-step-forward:before {
  content: "\f051";
}
.oscar .icon-eject:before {
  content: "\f052";
}
.oscar .icon-chevron-left:before {
  content: "\f053";
}
.oscar .icon-chevron-right:before {
  content: "\f054";
}
.oscar .icon-plus-sign:before {
  content: "\f055";
}
.oscar .icon-minus-sign:before {
  content: "\f056";
}
.oscar .icon-remove-sign:before {
  content: "\f057";
}
.oscar .icon-ok-sign:before {
  content: "\f058";
}
.oscar .icon-question-sign:before {
  content: "\f059";
}
.oscar .icon-info-sign:before {
  content: "\f05a";
}
.oscar .icon-screenshot:before {
  content: "\f05b";
}
.oscar .icon-remove-circle:before {
  content: "\f05c";
}
.oscar .icon-ok-circle:before {
  content: "\f05d";
}
.oscar .icon-ban-circle:before {
  content: "\f05e";
}
.oscar .icon-arrow-left:before {
  content: "\f060";
}
.oscar .icon-arrow-right:before {
  content: "\f061";
}
.oscar .icon-arrow-up:before {
  content: "\f062";
}
.oscar .icon-arrow-down:before {
  content: "\f063";
}
.oscar .icon-mail-forward:before,
.oscar .icon-share-alt:before {
  content: "\f064";
}
.oscar .icon-resize-full:before {
  content: "\f065";
}
.oscar .icon-resize-small:before {
  content: "\f066";
}
.oscar .icon-plus:before {
  content: "\f067";
}
.oscar .icon-minus:before {
  content: "\f068";
}
.oscar .icon-asterisk:before {
  content: "\f069";
}
.oscar .icon-exclamation-sign:before {
  content: "\f06a";
}
.oscar .icon-gift:before {
  content: "\f06b";
}
.oscar .icon-leaf:before {
  content: "\f06c";
}
.oscar .icon-fire:before {
  content: "\f06d";
}
.oscar .icon-eye-open:before {
  content: "\f06e";
}
.oscar .icon-eye-close:before {
  content: "\f070";
}
.oscar .icon-warning-sign:before {
  content: "\f071";
}
.oscar .icon-plane:before {
  content: "\f072";
}
.oscar .icon-calendar:before {
  content: "\f073";
}
.oscar .icon-random:before {
  content: "\f074";
}
.oscar .icon-comment:before {
  content: "\f075";
}
.oscar .icon-magnet:before {
  content: "\f076";
}
.oscar .icon-chevron-up:before {
  content: "\f077";
}
.oscar .icon-chevron-down:before {
  content: "\f078";
}
.oscar .icon-retweet:before {
  content: "\f079";
}
.oscar .icon-shopping-cart:before {
  content: "\f07a";
}
.oscar .icon-folder-close:before {
  content: "\f07b";
}
.oscar .icon-folder-open:before {
  content: "\f07c";
}
.oscar .icon-resize-vertical:before {
  content: "\f07d";
}
.oscar .icon-resize-horizontal:before {
  content: "\f07e";
}
.oscar .icon-bar-chart:before {
  content: "\f080";
}
.oscar .icon-twitter-sign:before {
  content: "\f081";
}
.oscar .icon-facebook-sign:before {
  content: "\f082";
}
.oscar .icon-camera-retro:before {
  content: "\f083";
}
.oscar .icon-key:before {
  content: "\f084";
}
.oscar .icon-gears:before,
.oscar .icon-cogs:before {
  content: "\f085";
}
.oscar .icon-comments:before {
  content: "\f086";
}
.oscar .icon-thumbs-up-alt:before {
  content: "\f087";
}
.oscar .icon-thumbs-down-alt:before {
  content: "\f088";
}
.oscar .icon-star-half:before {
  content: "\f089";
}
.oscar .icon-heart-empty:before {
  content: "\f08a";
}
.oscar .icon-signout:before {
  content: "\f08b";
}
.oscar .icon-linkedin-sign:before {
  content: "\f08c";
}
.oscar .icon-pushpin:before {
  content: "\f08d";
}
.oscar .icon-external-link:before {
  content: "\f08e";
}
.oscar .icon-signin:before {
  content: "\f090";
}
.oscar .icon-trophy:before {
  content: "\f091";
}
.oscar .icon-github-sign:before {
  content: "\f092";
}
.oscar .icon-upload-alt:before {
  content: "\f093";
}
.oscar .icon-lemon:before {
  content: "\f094";
}
.oscar .icon-phone:before {
  content: "\f095";
}
.oscar .icon-unchecked:before,
.oscar .icon-check-empty:before {
  content: "\f096";
}
.oscar .icon-bookmark-empty:before {
  content: "\f097";
}
.oscar .icon-phone-sign:before {
  content: "\f098";
}
.oscar .icon-twitter:before {
  content: "\f099";
}
.oscar .icon-facebook:before {
  content: "\f09a";
}
.oscar .icon-github:before {
  content: "\f09b";
}
.oscar .icon-unlock:before {
  content: "\f09c";
}
.oscar .icon-credit-card:before {
  content: "\f09d";
}
.oscar .icon-rss:before {
  content: "\f09e";
}
.oscar .icon-hdd:before {
  content: "\f0a0";
}
.oscar .icon-bullhorn:before {
  content: "\f0a1";
}
.oscar .icon-bell:before {
  content: "\f0a2";
}
.oscar .icon-certificate:before {
  content: "\f0a3";
}
.oscar .icon-hand-right:before {
  content: "\f0a4";
}
.oscar .icon-hand-left:before {
  content: "\f0a5";
}
.oscar .icon-hand-up:before {
  content: "\f0a6";
}
.oscar .icon-hand-down:before {
  content: "\f0a7";
}
.oscar .icon-circle-arrow-left:before {
  content: "\f0a8";
}
.oscar .icon-circle-arrow-right:before {
  content: "\f0a9";
}
.oscar .icon-circle-arrow-up:before {
  content: "\f0aa";
}
.oscar .icon-circle-arrow-down:before {
  content: "\f0ab";
}
.oscar .icon-globe:before {
  content: "\f0ac";
}
.oscar .icon-wrench:before {
  content: "\f0ad";
}
.oscar .icon-tasks:before {
  content: "\f0ae";
}
.oscar .icon-filter:before {
  content: "\f0b0";
}
.oscar .icon-briefcase:before {
  content: "\f0b1";
}
.oscar .icon-fullscreen:before {
  content: "\f0b2";
}
.oscar .icon-group:before {
  content: "\f0c0";
}
.oscar .icon-link:before {
  content: "\f0c1";
}
.oscar .icon-cloud:before {
  content: "\f0c2";
}
.oscar .icon-beaker:before {
  content: "\f0c3";
}
.oscar .icon-cut:before {
  content: "\f0c4";
}
.oscar .icon-copy:before {
  content: "\f0c5";
}
.oscar .icon-paperclip:before,
.oscar .icon-paper-clip:before {
  content: "\f0c6";
}
.oscar .icon-save:before {
  content: "\f0c7";
}
.oscar .icon-sign-blank:before {
  content: "\f0c8";
}
.oscar .icon-reorder:before {
  content: "\f0c9";
}
.oscar .icon-list-ul:before {
  content: "\f0ca";
}
.oscar .icon-list-ol:before {
  content: "\f0cb";
}
.oscar .icon-strikethrough:before {
  content: "\f0cc";
}
.oscar .icon-underline:before {
  content: "\f0cd";
}
.oscar .icon-table:before {
  content: "\f0ce";
}
.oscar .icon-magic:before {
  content: "\f0d0";
}
.oscar .icon-truck:before {
  content: "\f0d1";
}
.oscar .icon-pinterest:before {
  content: "\f0d2";
}
.oscar .icon-pinterest-sign:before {
  content: "\f0d3";
}
.oscar .icon-google-plus-sign:before {
  content: "\f0d4";
}
.oscar .icon-google-plus:before {
  content: "\f0d5";
}
.oscar .icon-money:before {
  content: "\f0d6";
}
.oscar .icon-caret-down:before {
  content: "\f0d7";
}
.oscar .icon-caret-up:before {
  content: "\f0d8";
}
.oscar .icon-caret-left:before {
  content: "\f0d9";
}
.oscar .icon-caret-right:before {
  content: "\f0da";
}
.oscar .icon-columns:before {
  content: "\f0db";
}
.oscar .icon-sort:before {
  content: "\f0dc";
}
.oscar .icon-sort-down:before {
  content: "\f0dd";
}
.oscar .icon-sort-up:before {
  content: "\f0de";
}
.oscar .icon-envelope:before {
  content: "\f0e0";
}
.oscar .icon-linkedin:before {
  content: "\f0e1";
}
.oscar .icon-rotate-left:before,
.oscar .icon-undo:before {
  content: "\f0e2";
}
.oscar .icon-legal:before {
  content: "\f0e3";
}
.oscar .icon-dashboard:before {
  content: "\f0e4";
}
.oscar .icon-comment-alt:before {
  content: "\f0e5";
}
.oscar .icon-comments-alt:before {
  content: "\f0e6";
}
.oscar .icon-bolt:before {
  content: "\f0e7";
}
.oscar .icon-sitemap:before {
  content: "\f0e8";
}
.oscar .icon-umbrella:before {
  content: "\f0e9";
}
.oscar .icon-paste:before {
  content: "\f0ea";
}
.oscar .icon-lightbulb:before {
  content: "\f0eb";
}
.oscar .icon-exchange:before {
  content: "\f0ec";
}
.oscar .icon-cloud-download:before {
  content: "\f0ed";
}
.oscar .icon-cloud-upload:before {
  content: "\f0ee";
}
.oscar .icon-user-md:before {
  content: "\f0f0";
}
.oscar .icon-stethoscope:before {
  content: "\f0f1";
}
.oscar .icon-suitcase:before {
  content: "\f0f2";
}
.oscar .icon-bell-alt:before {
  content: "\f0f3";
}
.oscar .icon-coffee:before {
  content: "\f0f4";
}
.oscar .icon-food:before {
  content: "\f0f5";
}
.oscar .icon-file-text-alt:before {
  content: "\f0f6";
}
.oscar .icon-building:before {
  content: "\f0f7";
}
.oscar .icon-hospital:before {
  content: "\f0f8";
}
.oscar .icon-ambulance:before {
  content: "\f0f9";
}
.oscar .icon-medkit:before {
  content: "\f0fa";
}
.oscar .icon-fighter-jet:before {
  content: "\f0fb";
}
.oscar .icon-beer:before {
  content: "\f0fc";
}
.oscar .icon-h-sign:before {
  content: "\f0fd";
}
.oscar .icon-plus-sign-alt:before {
  content: "\f0fe";
}
.oscar .icon-double-angle-left:before {
  content: "\f100";
}
.oscar .icon-double-angle-right:before {
  content: "\f101";
}
.oscar .icon-double-angle-up:before {
  content: "\f102";
}
.oscar .icon-double-angle-down:before {
  content: "\f103";
}
.oscar .icon-angle-left:before {
  content: "\f104";
}
.oscar .icon-angle-right:before {
  content: "\f105";
}
.oscar .icon-angle-up:before {
  content: "\f106";
}
.oscar .icon-angle-down:before {
  content: "\f107";
}
.oscar .icon-desktop:before {
  content: "\f108";
}
.oscar .icon-laptop:before {
  content: "\f109";
}
.oscar .icon-tablet:before {
  content: "\f10a";
}
.oscar .icon-mobile-phone:before {
  content: "\f10b";
}
.oscar .icon-circle-blank:before {
  content: "\f10c";
}
.oscar .icon-quote-left:before {
  content: "\f10d";
}
.oscar .icon-quote-right:before {
  content: "\f10e";
}
.oscar .icon-spinner:before {
  content: "\f110";
}
.oscar .icon-circle:before {
  content: "\f111";
}
.oscar .icon-mail-reply:before,
.oscar .icon-reply:before {
  content: "\f112";
}
.oscar .icon-github-alt:before {
  content: "\f113";
}
.oscar .icon-folder-close-alt:before {
  content: "\f114";
}
.oscar .icon-folder-open-alt:before {
  content: "\f115";
}
.oscar .icon-expand-alt:before {
  content: "\f116";
}
.oscar .icon-collapse-alt:before {
  content: "\f117";
}
.oscar .icon-smile:before {
  content: "\f118";
}
.oscar .icon-frown:before {
  content: "\f119";
}
.oscar .icon-meh:before {
  content: "\f11a";
}
.oscar .icon-gamepad:before {
  content: "\f11b";
}
.oscar .icon-keyboard:before {
  content: "\f11c";
}
.oscar .icon-flag-alt:before {
  content: "\f11d";
}
.oscar .icon-flag-checkered:before {
  content: "\f11e";
}
.oscar .icon-terminal:before {
  content: "\f120";
}
.oscar .icon-code:before {
  content: "\f121";
}
.oscar .icon-reply-all:before {
  content: "\f122";
}
.oscar .icon-mail-reply-all:before {
  content: "\f122";
}
.oscar .icon-star-half-full:before,
.oscar .icon-star-half-empty:before {
  content: "\f123";
}
.oscar .icon-location-arrow:before {
  content: "\f124";
}
.oscar .icon-crop:before {
  content: "\f125";
}
.oscar .icon-code-fork:before {
  content: "\f126";
}
.oscar .icon-unlink:before {
  content: "\f127";
}
.oscar .icon-question:before {
  content: "\f128";
}
.oscar .icon-info:before {
  content: "\f129";
}
.oscar .icon-exclamation:before {
  content: "\f12a";
}
.oscar .icon-superscript:before {
  content: "\f12b";
}
.oscar .icon-subscript:before {
  content: "\f12c";
}
.oscar .icon-eraser:before {
  content: "\f12d";
}
.oscar .icon-puzzle-piece:before {
  content: "\f12e";
}
.oscar .icon-microphone:before {
  content: "\f130";
}
.oscar .icon-microphone-off:before {
  content: "\f131";
}
.oscar .icon-shield:before {
  content: "\f132";
}
.oscar .icon-calendar-empty:before {
  content: "\f133";
}
.oscar .icon-fire-extinguisher:before {
  content: "\f134";
}
.oscar .icon-rocket:before {
  content: "\f135";
}
.oscar .icon-maxcdn:before {
  content: "\f136";
}
.oscar .icon-chevron-sign-left:before {
  content: "\f137";
}
.oscar .icon-chevron-sign-right:before {
  content: "\f138";
}
.oscar .icon-chevron-sign-up:before {
  content: "\f139";
}
.oscar .icon-chevron-sign-down:before {
  content: "\f13a";
}
.oscar .icon-html5:before {
  content: "\f13b";
}
.oscar .icon-css3:before {
  content: "\f13c";
}
.oscar .icon-anchor:before {
  content: "\f13d";
}
.oscar .icon-unlock-alt:before {
  content: "\f13e";
}
.oscar .icon-bullseye:before {
  content: "\f140";
}
.oscar .icon-ellipsis-horizontal:before {
  content: "\f141";
}
.oscar .icon-ellipsis-vertical:before {
  content: "\f142";
}
.oscar .icon-rss-sign:before {
  content: "\f143";
}
.oscar .icon-play-sign:before {
  content: "\f144";
}
.oscar .icon-ticket:before {
  content: "\f145";
}
.oscar .icon-minus-sign-alt:before {
  content: "\f146";
}
.oscar .icon-check-minus:before {
  content: "\f147";
}
.oscar .icon-level-up:before {
  content: "\f148";
}
.oscar .icon-level-down:before {
  content: "\f149";
}
.oscar .icon-check-sign:before {
  content: "\f14a";
}
.oscar .icon-edit-sign:before {
  content: "\f14b";
}
.oscar .icon-external-link-sign:before {
  content: "\f14c";
}
.oscar .icon-share-sign:before {
  content: "\f14d";
}
.oscar .icon-compass:before {
  content: "\f14e";
}
.oscar .icon-collapse:before {
  content: "\f150";
}
.oscar .icon-collapse-top:before {
  content: "\f151";
}
.oscar .icon-expand:before {
  content: "\f152";
}
.oscar .icon-euro:before,
.oscar .icon-eur:before {
  content: "\f153";
}
.oscar .icon-gbp:before {
  content: "\f154";
}
.oscar .icon-dollar:before,
.oscar .icon-usd:before {
  content: "\f155";
}
.oscar .icon-rupee:before,
.oscar .icon-inr:before {
  content: "\f156";
}
.oscar .icon-yen:before,
.oscar .icon-jpy:before {
  content: "\f157";
}
.oscar .icon-renminbi:before,
.oscar .icon-cny:before {
  content: "\f158";
}
.oscar .icon-won:before,
.oscar .icon-krw:before {
  content: "\f159";
}
.oscar .icon-bitcoin:before,
.oscar .icon-btc:before {
  content: "\f15a";
}
.oscar .icon-file:before {
  content: "\f15b";
}
.oscar .icon-file-text:before {
  content: "\f15c";
}
.oscar .icon-sort-by-alphabet:before {
  content: "\f15d";
}
.oscar .icon-sort-by-alphabet-alt:before {
  content: "\f15e";
}
.oscar .icon-sort-by-attributes:before {
  content: "\f160";
}
.oscar .icon-sort-by-attributes-alt:before {
  content: "\f161";
}
.oscar .icon-sort-by-order:before {
  content: "\f162";
}
.oscar .icon-sort-by-order-alt:before {
  content: "\f163";
}
.oscar .icon-thumbs-up:before {
  content: "\f164";
}
.oscar .icon-thumbs-down:before {
  content: "\f165";
}
.oscar .icon-youtube-sign:before {
  content: "\f166";
}
.oscar .icon-youtube:before {
  content: "\f167";
}
.oscar .icon-xing:before {
  content: "\f168";
}
.oscar .icon-xing-sign:before {
  content: "\f169";
}
.oscar .icon-youtube-play:before {
  content: "\f16a";
}
.oscar .icon-dropbox:before {
  content: "\f16b";
}
.oscar .icon-stackexchange:before {
  content: "\f16c";
}
.oscar .icon-instagram:before {
  content: "\f16d";
}
.oscar .icon-flickr:before {
  content: "\f16e";
}
.oscar .icon-adn:before {
  content: "\f170";
}
.oscar .icon-bitbucket:before {
  content: "\f171";
}
.oscar .icon-bitbucket-sign:before {
  content: "\f172";
}
.oscar .icon-tumblr:before {
  content: "\f173";
}
.oscar .icon-tumblr-sign:before {
  content: "\f174";
}
.oscar .icon-long-arrow-down:before {
  content: "\f175";
}
.oscar .icon-long-arrow-up:before {
  content: "\f176";
}
.oscar .icon-long-arrow-left:before {
  content: "\f177";
}
.oscar .icon-long-arrow-right:before {
  content: "\f178";
}
.oscar .icon-apple:before {
  content: "\f179";
}
.oscar .icon-windows:before {
  content: "\f17a";
}
.oscar .icon-android:before {
  content: "\f17b";
}
.oscar .icon-linux:before {
  content: "\f17c";
}
.oscar .icon-dribbble:before {
  content: "\f17d";
}
.oscar .icon-skype:before {
  content: "\f17e";
}
.oscar .icon-foursquare:before {
  content: "\f180";
}
.oscar .icon-trello:before {
  content: "\f181";
}
.oscar .icon-female:before {
  content: "\f182";
}
.oscar .icon-male:before {
  content: "\f183";
}
.oscar .icon-gittip:before {
  content: "\f184";
}
.oscar .icon-sun:before {
  content: "\f185";
}
.oscar .icon-moon:before {
  content: "\f186";
}
.oscar .icon-archive:before {
  content: "\f187";
}
.oscar .icon-bug:before {
  content: "\f188";
}
.oscar .icon-vk:before {
  content: "\f189";
}
.oscar .icon-weibo:before {
  content: "\f18a";
}
.oscar .icon-renren:before {
  content: "\f18b";
}
input[name="reference"],
input[name="amount"] {
  padding: 8px;
}
div.oscar {
  overflow-x: scroll;
}
.oscar .help-block {
  display: block;
  padding: 0;
}
label[for] {
  cursor: pointer;
}
.sortable-handle {
  cursor: grab;
}
.oscar .sortable-handle label {
  width: 1px;
  margin-right: 10px;
}
.oscar .sortable-handle input[type="checkbox"] {
  margin-left: 24px;
  margin-top: 1.2em;
}
table.listing {
  table-layout: fixed;
}
table.listing thead th {
  overflow: hidden;
  text-overflow: ellipsis;
  word-wrap: break-word;
}
.form-inline #id_q.form-control {
  display: block;
  width: initial;
}
form.order_table table tbody tr td {
  word-wrap: break-word;
}
.orderstatus_bubble {
  width: 50px ;
  height: 50px ;
  border-radius: 10px ;
  display: flex ;
  position: relative;
}
.orderstatus_bubble > input {
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  margin: 0;
  width: 20px;
}
.orderstatus_bubble.paid {
  background-color: #fff3cd;
}
.orderstatus_bubble.complete {
  background-color: #d4edda;
}
.orderstatus_bubble.cancelled {
  background-color: #f8d7da;
}
.orderstatus_bubble.new {
  background-color: #00a9ff;
}
.orderstatus_bubble.pending-payment {
  background-color: #ff9d00;
}
.orderstatus_bubble.delayed-payment {
  background-color: #ce84ff;
}
.orderstatus_bubble.refund {
  background-color: #ff9859;
}
/* Footer in settings menu fix */
.nav-submenu ul .footer {
  position: unset !important;
}
.pagination {
  display: flex;
}
.pagination li {
  margin-right: 0.5rem;
}
#page-reorder-form table.listing colgroup col:first-child {
  width: 4%;
}

/*# sourceMappingURL=wagtail_oscar_dashboard.css.map */
