import sys

from wagtail.utils.deprecation import MovedDefinitionHandler

MOVED_DEFINITIONS = {
    "get_wagtailsite": "ocyan.plugin.wagtail_utils.utils",
    "get_wagtailsettings": "ocyan.plugin.wagtail_utils.utils",
    "get_offline_request": "ocyan.plugin.wagtail_utils.utils",
    "get_default_site": "ocyan.plugin.wagtail_utils.utils",
    "StaticSrcFinder": "ocyan.plugin.wagtail_utils.utils",
}

sys.modules[__name__] = MovedDefinitionHandler(
    sys.modules[__name__], MOVED_DEFINITIONS, DeprecationWarning
)
