# -*- coding: utf-8 -*-
from ocyan.plugin.oscar.info import OSCAR_NEEDS_OXYAN

if OSCAR_NEEDS_OXYAN:
    from .entrypoint import WagtailOscar3IntegrationConfig  # noqa
else:
    from .entrypoint import WagtailOscarIntegrationConfig  # noqa

default_app_config = "ocyan.plugin.wagtail_oscar_integration.apps.OcyanPluginWagtailOscarIntegrationAppConfig"
