{% load styling_tags %}

<a class="c-link {% get_styling_classes self.styling %}" href="{{ self.category.get_absolute_url }}" {% get_styling self.styling %}>
<div class="d-inline-block c-categories c-hover">
   <span class="c-name">{% if self.label %}{{ self.label }}{% else %}{{ self.category.name }}{% endif %}</span>
</div>
</a>