{% load wagtailcore_tags purchase_info_tags %}

{% purchase_info_for_product request value as session %}

<div class="product_price">
    {% include "catalogue/partials/stock_record.html" with product=value %}
</div>
{% include "catalogue/partials/add_to_basket_form.html" with product=value %}
