@import "oscar/scss/dashboard/variables";

@import "scss/vendor/bootstrap/bootstrap";

// Oscar dashboard styles
@import "oscar/scss/alerts";
@import "oscar/scss/dashboard/base";
@import "oscar/scss/dashboard/buttons";
@import "oscar/scss/dashboard/catalogue";
@import "oscar/scss/dashboard/navbar";
@import "oscar/scss/dashboard/forms";
@import "oscar/scss/dashboard/tables";
@import "oscar/scss/dashboard/index";
