{% extends "oscar/dashboard/layout.html" %}

{% load wagtailadmin_tags staticfiles i18n ocyan_main %}

{% block oscarcss %}
    <link rel="stylesheet" href="{% static "oscar/js/select2/select2.min.css" %}" />
    <link rel="stylesheet" href="{% static "oscar/css/select2-bootstrap.min.css" %}" />
    <link rel="stylesheet" href="{% static "oscar/js/bootstrap4-datetimepicker/tempusdominus-bootstrap-4.min.css" %}" />
{% endblock %}

{% block oscarjs %}
    <script src="{% versioned_static "wagtailadmin/js/chooser-widget-telepath.js" %}"></script>
    <script src="{% versioned_static "wagtailadmin/js/chooser-widget.js" %}"></script>
    <script src="{% versioned_static "wagtailsnippets/js/snippet-chooser-telepath.js" %}"></script>
    <script src="{% static "ocyan_plugin_wagtail_oscar_integration/boostrap_no_modal.min.js" %}"></script>

    <!-- Oscar -->
    <script src="{% static "oscar/js/oscar/ui.js" %}"></script>

    {# jQuery plugins #}
    <script src="{% static "oscar/js/mousewheel/jquery.mousewheel.js" %}"></script>
    <script src="{% static "oscar/js/bootstrap4-datetimepicker/moment-with-locales.min.js" %}"></script>
    <script src="{% static "oscar/js/bootstrap4-datetimepicker/tempusdominus-bootstrap-4.min.js" %}"></script>
    <script src="{% static "oscar/js/inputmask/jquery.inputmask.min.js" %}"></script>
    <script src="{% static "oscar/js/select2/select2.min.js" %}"></script>
    <script src="{% static "oscar/js/oscar/dashboard.js" %}"></script>
    <script src="{% static "oscar/js/oscar/RelatedObjectLookups.js" %}"></script>
    <script src="{% static "oscar/js/tinymce/tinymce.min.js" %}"></script>
    <script src="{% static "oscar/js/tinymce/jquery.tinymce.min.js" %}"></script>
    <script src="{% static "ocyan_plugin_wagtail_oscar_integration/sortable.min.js" %}"></script>

{% endblock %}

{% block oscardashboardinit %}
options = {
    'languageCode': '{{ LANGUAGE_CODE }}',
    'tinyConfig': {
        plugins: "link lists media",
        toolbar: "styles | removeformat | bold italic blockquote | bullist numlist | link media",
        contextmenu: false
    }
};
oscar.dashboard.init(options);
{% endblock oscardashboardinit %}