/* FONT PATH
 * -------------------------- */

@font-face {
  font-family: "OscarFontAwesome";
  src: url("@{FontAwesomePath}/fontawesome-webfont.eot?v=@{FontAwesomeVersion}");
  src: url("@{FontAwesomePath}/fontawesome-webfont.eot?#iefix&v=@{FontAwesomeVersion}")
      format("embedded-opentype"),
    url("@{FontAwesomePath}/fontawesome-webfont.woff?v=@{FontAwesomeVersion}")
      format("woff"),
    url("@{FontAwesomePath}/fontawesome-webfont.ttf?v=@{FontAwesomeVersion}")
      format("truetype"),
    url("@{FontAwesomePath}/fontawesome-webfont.svg#fontawesomeregular?v=@{FontAwesomeVersion}")
      format("svg");
  //  src: url('@{FontAwesomePath}/FontAwesome.otf') format('opentype'); // used when developing fonts
  font-weight: normal;
  font-style: normal;
}
