.oscar{
    overflow-x: unset !important;
    .modal .close{
        background: unset !important;
    }
}

#SearchModal{
    #id_response_format{
        width: 100% !important;
        height: 100% !important;
        display: flex !important;
        border: unset !important;
        padding-right: calc(var(--bs-gutter-x) * .5);
        padding-left: calc(var(--bs-gutter-x) * .5);
        label{
            display: block;
            width: 100%;
            height: 100%;
            line-height: 28px;
            &[for="id_response_format_0"]{
                &:first-child{
                    margin-right: 2rem;
                }
            }
        }
    }
    input[type=radio]{
        margin-right: 10px !important;
        &:before{
            content: unset !important;
        }
        &::after{
            position: relative !important;
        }
        &:checked{
            border: unset;
        }
    }
    .form-group{
        margin-bottom: 1rem;
    }
    .input-group-text{
        height: 100% !important;
    }
}

.page-header{
    a.btn{
        display: inline-block;
        font-weight: 400;
        line-height: 1.5;
        color: #212529;
        text-align: center;
        text-decoration: none;
        vertical-align: middle;
        cursor: pointer;
        user-select: none;
        background-color: transparent;
        border: 1px solid transparent;
        padding: 0.375rem 0.75rem;
        font-size: 0.8rem;
        border-radius: 0.25rem;
        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        background-color: var(--w-color-icon-primary);
        border-color: var(--w-color-icon-primary);
    }
}

@media (prefers-color-scheme: dark) {
    /* Apply dark theme styles here */
    .btn.btn-secondary{
        color: black;
    }
    .oscar{
        a[data-target="#SearchModal"]{
            color: white;
        }
    }
    .tabbable.dashboard{
        .nav.nav-tabs{
            .nav-item, .nav-link{
                a{
                    color: white !important;
                }
            }
        }
    }
    .select2-selection__rendered{
        color: white !important;
    }
    .select2-selection.select2-selection--multiple{
        .select2-selection__choice{
            color: black;
            span{
                color: black;
            }
        }
    }
    .btn-toolbar{
        .dropdown-menu{
            li{
                a{
                    color: white;
                }
                &:hover{
                    a{
                        color: black;
                    }
                }
            }
        }
    }
    span.true{
        color:white;
    }
}

@media (prefers-color-scheme: light) {
    /* Apply light theme styles here */
    .page-header{
        a.btn{
            color: white;
        }
    }
    .tabbable.dashboard{
        .nav.nav-tabs{
            .nav-item, .nav-link{
                background-color: unset !important;
                a{
                    color: var(--w-color-text-label) !important;
                }
                &.active{
                    a{
                    border: 1px solid #e9ecef;
                    }
                }
                
            }
        }
    }
    .select2-results__option{
        &[aria-selected="true"]{
            color: white !important;
        }
    }
    .btn-toolbar{
        .dropdown-menu{
            li{
                a{
                    color: white;
                }
            }
        }
    }
}