"""Optional uWSGI cron support without making uWSGI a runtime requirement."""

try:
    from uwsgidecorators import cron  # type: ignore[import-not-found]
except ImportError:

    def cron(*_args, **_kwargs):
        """Leave the callback callable when the process is not managed by uWSGI."""

        def decorate(function):
            return function

        return decorate
