{% load wagtailadmin_tags sorl_thumbnail %}

<td class="no-padding nice-padding">
    <div class="title-wrapper">
        {% block title %}
            {% if link_url %}
                <a {% include "wagtailadmin/shared/attrs.html" with attrs=link_attrs %}><img src="{% thumbnail value '35' crop='center' %}" alt="{{ value.name }}"/></a>
            {% elif label_id %}
                <label for="{{ label_id }}">{{ value }}</label>
            {% else %}
                {{ value }}
            {% endif %}
        {% endblock %}
    </div>
    {% if buttons %}
        <ul class="actions">
            {% block buttons %}
                {% include "wagtailadmin/shared/buttons.html" %}
            {% endblock %}
        </ul>
    {% endif %}
</td>

