{% if self.category.image %}
<a href="{{self.category.get_absolute_url}}">
    <div class="category-image-chooser">
        <img src="{{self.category.image.url}}" width="100%" height="auto" />
        <div class="category-chooser-text-wrapper">
            <h2>{{self.category.name}}</h2>
        </div>
    </div>
</a>
{% endif %}
