from ocyan.core.fender import config

INCLUDE_CHILD_PRODUCTS_IN_SITEMAP = config.get(
    "wagtail_oscar", "sitemap_include_child_products", False
)

CACHE_DURATION = config.get("wagtail_oscar", "sitemap_cache_duration", 86400)

PAGE_SIZE = config.get("wagtail_oscar", "sitemap_page_size", 50000)
ALTERNATES = config.get("wagtail_oscar", "sitemap_alternates", True)
