{% extends "wagtailadmin/base.html" %}
{% load ocyan_main %}

{% block furniture %}
    {# This is just a wrapper so I can remove the sidebar with CSS. #}
    {% if is_popup %}
    <div class="in_popup">
        {{ block.super }}
    </div>
    {% else %}
        {{ block.super }}
    {% endif %}
{% endblock %}
