from wagtail.users.apps import WagtailUsersAppConfig


class CustomUsersAppConfig(WagtailUsersAppConfig):
    user_viewset = "ocyan.plugin.wagtail_oscar_integration.wagtail_user_extension.viewsets.UserViewSet"
