{% extends "catalogue/partials/product.html" %}

{% load ocyan_thumbnail ocyanjson %}

{% block product_image %}
    {% ocyanjson "oscar" "product_image_geometry" 'x200' as product_image_geometry %}
    <div class="image_container">
        <a href="{{ product.get_absolute_url }}">
            {% lazy_owl_picture product.primary_image.original product_image_geometry upscale=False alt=product.get_title %}
        </a>
    </div>
{% endblock %}
