# -*- coding: utf-8 -*-
from django.apps import AppConfig


class OcyanPluginWagtailOscarIntegrationAppConfig(AppConfig):
    name = "ocyan.plugin.wagtail_oscar_integration"
    label = "wagtail_oscar_integration"
