aside.nav-wrapper {
    .oscar {
        a.icon {
            &.fa-list:before {
                content: "\e028";
            }
            &.fa-sitemap:before {
                content: "\f0e8";
                font-family: 'Font Awesome 5 Free';
                font-weight: 900;
            }
            &.fa-shopping-cart:before {
                content: "\f07a";
                font-family: 'Font Awesome 5 Free';
                font-weight: 900;
            }
            &.fa-users:before {
                content: "\f0c0";
                font-family: 'Font Awesome 5 Free';
                font-weight: 900;
            }
            &.fa-bullhorn:before {
                content: "\f0a1";
                font-family: 'Font Awesome 5 Free';
                font-weight: 900;
            }
            &.fa-folder:before {
                content: "\f07b";
                font-family: 'Font Awesome 5 Free';
                font-weight: 900;
            }
            &.fa-chart-bar:before {
                content: "\f080";
                font-family: 'Font Awesome 5 Free';
                font-weight: 900;
            }
        }
    }
}
