# -*- coding: utf-8 -*-
from setuptools import find_namespace_packages, setup

install_requires: list = [
    "ocyan.core",
    "ocyan.plugin.wagtail",
    "ocyan.plugin.wagtail_utils",
    "ocyan.plugin.oscar",
    "ocyan.plugin.oscar_elasticsearch",
    "lxml",
]

extras_require: dict = {
    "test": [
        "ocyan.plugin.testing",
        "wheel",
        "empty_testproject",
        "pylint-django",
        "isort",
        "ruff",
        "vdt.versionplugin.wheel",
        "coverage",
        "beautifulsoup4",
        "ocyan.plugin.coyote",
    ]
}

PACKAGE_CLASSIFIERS = [
    "License :: Other/Proprietary License",
    "Framework :: Ocyan",
    "Environment :: Plugins",
]

setup(
    name="ocyan.plugin.wagtail_oscar_integration",
    version="2.0.2rc1",
    url="https://git.mandelblog.com/mandel-plugins/ocyan.plugin.wagtail_oscar_integration",
    author="Mandel",
    author_email="info@mandelblog.com",
    description="Integrates Oscar dashboard with Wagtail dashboard.",
    packages=find_namespace_packages(include=["ocyan.*"]),
    include_package_data=True,
    python_requires=">=3.6",
    install_requires=install_requires,
    extras_require=extras_require,
    classifiers=PACKAGE_CLASSIFIERS,
)
