<div class="owl-carousel owl-theme product-slider">
    {% for product_slide in self %}
        {% if product_slide.product is not None %}
            {% include "roadrunner_bs4/partials/product.html" with product=product_slide.product %}
        {% endif %}
    {% endfor %}
</div>
